#######################################################################
# Port of ntc.js originally created by Chirag Mehta                   #
# +-----------------------------------------------------------------+ #
# |                  http://chir.ag/projects/ntc                    | #
# |-----------------------------------------------------------------| #
# |               ntc js (Name that Color JavaScript)               | #
# +-----------------------------------------------------------------+ #
#                                                                     #
# This script is released under the: Creative Commons License:        #
# Attribution 2.5 http://creativecommons.org/licenses/by/2.5/         #
#######################################################################

class Ntc
  attr_accessor :color

  def initialize(color)
    @color = color.upcase
    if @color.length < 3 || @color.length > 7
      raise InputError.new(@color), "Color must be in the form #RGB or #RRGGBB"
    end
    if @color.length % 3 == 0
      @color = "#" + @color
    end
    if @color.length == 4
      @color = "#" + @color[1] * 2 + @color[2] * 2 + @color[3] * 2
    end
  end

  # adopted from: Farbtastic 1.2
  # http://acko.net/dev/farbtastic
  def rgb
    [('0x' + @color[1..2]).to_i(16), ('0x' + @color[3..4]).to_i(16),('0x' + @color[5..6]).to_i(16)]
  end

  # adopted from: Farbtastic 1.2
  # http://acko.net/dev/farbtastic
  def hsl
    rgb = self.rgb.map {|v| v.to_f / 255}
    r, g, b = rgb

    min = [r, [g, b].min].min
    max = [r, [g, b].max].max
    delta = max - min
    l = (min + max) / 2

    s = 0
    if (l > 0) and (l < 1)
      s = delta / (l < 0.5 ? (2 * l) : (2 - 2 * l))
    end

    h = 0
    if delta > 0
      if (max == r && max != g)
        h += (g - b) / delta
      end
      if (max == g && max != b)
        h += (2 + (b - r) / delta)
      end
      if (max == b && max != r)
        h += (4 + (r - g) / delta)
      end
      h /= 6
    end

    return [(h * 255).to_i, (s * 255).to_i, (l * 255).to_i]
  end

  def name
    rgb = self.rgb
    r, g, b = rgb
    hsl = self.hsl
    h, s, l = hsl
    ndf1 = 0
    ndf2 = 0
    ndf = 0
    cl = -1
    df = -1

    $names.length.times do |i|
      if @color == "#" + $names[i][0]
        return ["#" + $names[i][0], $names[i][1], true]
      end
      ndf1 = (r - $names[i][2]) ** 2 + (g - $names[i][3]) ** 2 + (b - $names[i][4]) ** 2
      ndf2 = (h - $names[i][5]) ** 2 + (s - $names[i][6]) ** 2 + (l - $names[i][7]) ** 2
      ndf = ndf1 + ndf2 * 2
      if (df < 0) or (df > ndf)
        df = ndf
        cl = i
      end
    end

    if cl < 0
      raise InputError.new(@color), "Color must be in the form #RGB or #RRGGBB"
    else
      return ["#" + $names[cl][0], $names[cl][1], false]
    end
  end
end

class InputError < StandardError
  attr_accessor :object

  def initialize(object)
    @object = object
  end
end

$names = [
  [
    "000000",
    "Black",
    0,
    0,
    0,
    0,
    0,
    0
  ],
  [
    "000080",
    "Navy Blue",
    0,
    0,
    128,
    170,
    255,
    64
  ],
  [
    "0000C8",
    "Dark Blue",
    0,
    0,
    200,
    170,
    255,
    100
  ],
  [
    "0000FF",
    "Blue",
    0,
    0,
    255,
    170,
    255,
    127
  ],
  [
    "000741",
    "Stratos",
    0,
    7,
    65,
    165,
    255,
    32
  ],
  [
    "001B1C",
    "Swamp",
    0,
    27,
    28,
    129,
    255,
    14
  ],
  [
    "002387",
    "Resolution Blue",
    0,
    35,
    135,
    158,
    255,
    67
  ],
  [
    "002900",
    "Deep Fir",
    0,
    41,
    0,
    85,
    255,
    20
  ],
  [
    "002E20",
    "Burnham",
    0,
    46,
    32,
    114,
    255,
    23
  ],
  [
    "002FA7",
    "International Klein Blue",
    0,
    47,
    167,
    158,
    255,
    83
  ],
  [
    "003153",
    "Prussian Blue",
    0,
    49,
    83,
    144,
    255,
    41
  ],
  [
    "003366",
    "Midnight Blue",
    0,
    51,
    102,
    148,
    255,
    51
  ],
  [
    "003399",
    "Smalt",
    0,
    51,
    153,
    155,
    255,
    76
  ],
  [
    "003532",
    "Deep Teal",
    0,
    53,
    50,
    125,
    255,
    26
  ],
  [
    "003E40",
    "Cyprus",
    0,
    62,
    64,
    128,
    255,
    32
  ],
  [
    "004620",
    "Kaitoke Green",
    0,
    70,
    32,
    104,
    255,
    35
  ],
  [
    "0047AB",
    "Cobalt",
    0,
    71,
    171,
    152,
    255,
    85
  ],
  [
    "004816",
    "Crusoe",
    0,
    72,
    22,
    97,
    255,
    36
  ],
  [
    "004950",
    "Sherpa Blue",
    0,
    73,
    80,
    131,
    255,
    40
  ],
  [
    "0056A7",
    "Endeavour",
    0,
    86,
    167,
    148,
    255,
    83
  ],
  [
    "00581A",
    "Camarone",
    0,
    88,
    26,
    97,
    255,
    44
  ],
  [
    "0066CC",
    "Science Blue",
    0,
    102,
    204,
    148,
    255,
    102
  ],
  [
    "0066FF",
    "Blue Ribbon",
    0,
    102,
    255,
    153,
    255,
    127
  ],
  [
    "00755E",
    "Tropical Rain Forest",
    0,
    117,
    94,
    119,
    255,
    58
  ],
  [
    "0076A3",
    "Allports",
    0,
    118,
    163,
    139,
    255,
    81
  ],
  [
    "007BA7",
    "Deep Cerulean",
    0,
    123,
    167,
    138,
    255,
    83
  ],
  [
    "007EC7",
    "Lochmara",
    0,
    126,
    199,
    143,
    255,
    99
  ],
  [
    "007FFF",
    "Azure Radiance",
    0,
    127,
    255,
    148,
    255,
    127
  ],
  [
    "008080",
    "Teal",
    0,
    128,
    128,
    127,
    255,
    64
  ],
  [
    "0095B6",
    "Bondi Blue",
    0,
    149,
    182,
    135,
    255,
    91
  ],
  [
    "009DC4",
    "Pacific Blue",
    0,
    157,
    196,
    135,
    255,
    98
  ],
  [
    "00A693",
    "Persian Green",
    0,
    166,
    147,
    122,
    255,
    83
  ],
  [
    "00A86B",
    "Jade",
    0,
    168,
    107,
    112,
    255,
    84
  ],
  [
    "00CC99",
    "Caribbean Green",
    0,
    204,
    153,
    116,
    255,
    102
  ],
  [
    "00CCCC",
    "Robin's Egg Blue",
    0,
    204,
    204,
    127,
    255,
    102
  ],
  [
    "00FF00",
    "Green",
    0,
    255,
    0,
    85,
    255,
    127
  ],
  [
    "00FF7F",
    "Spring Green",
    0,
    255,
    127,
    106,
    255,
    127
  ],
  [
    "00FFFF",
    "Cyan / Aqua",
    0,
    255,
    255,
    127,
    255,
    127
  ],
  [
    "010D1A",
    "Blue Charcoal",
    1,
    13,
    26,
    149,
    236,
    13
  ],
  [
    "011635",
    "Midnight",
    1,
    22,
    53,
    152,
    245,
    27
  ],
  [
    "011D13",
    "Holly",
    1,
    29,
    19,
    112,
    238,
    15
  ],
  [
    "012731",
    "Daintree",
    1,
    39,
    49,
    136,
    244,
    25
  ],
  [
    "01361C",
    "Cardin Green",
    1,
    54,
    28,
    106,
    245,
    27
  ],
  [
    "01371A",
    "County Green",
    1,
    55,
    26,
    104,
    245,
    28
  ],
  [
    "013E62",
    "Astronaut Blue",
    1,
    62,
    98,
    143,
    249,
    49
  ],
  [
    "013F6A",
    "Regal Blue",
    1,
    63,
    106,
    144,
    250,
    53
  ],
  [
    "014B43",
    "Aqua Deep",
    1,
    75,
    67,
    122,
    248,
    38
  ],
  [
    "015E85",
    "Orient",
    1,
    94,
    133,
    140,
    251,
    67
  ],
  [
    "016162",
    "Blue Stone",
    1,
    97,
    98,
    127,
    249,
    49
  ],
  [
    "016D39",
    "Fun Green",
    1,
    109,
    57,
    107,
    250,
    54
  ],
  [
    "01796F",
    "Pine Green",
    1,
    121,
    111,
    123,
    250,
    60
  ],
  [
    "017987",
    "Blue Lagoon",
    1,
    121,
    135,
    131,
    251,
    68
  ],
  [
    "01826B",
    "Deep Sea",
    1,
    130,
    107,
    119,
    251,
    65
  ],
  [
    "01A368",
    "Green Haze",
    1,
    163,
    104,
    112,
    251,
    81
  ],
  [
    "022D15",
    "English Holly",
    2,
    45,
    21,
    103,
    233,
    23
  ],
  [
    "02402C",
    "Sherwood Green",
    2,
    64,
    44,
    113,
    239,
    32
  ],
  [
    "02478E",
    "Congress Blue",
    2,
    71,
    142,
    149,
    247,
    72
  ],
  [
    "024E46",
    "Evening Sea",
    2,
    78,
    70,
    123,
    242,
    40
  ],
  [
    "026395",
    "Bahama Blue",
    2,
    99,
    149,
    141,
    248,
    75
  ],
  [
    "02866F",
    "Observatory",
    2,
    134,
    111,
    120,
    247,
    68
  ],
  [
    "02A4D3",
    "Cerulean",
    2,
    164,
    211,
    137,
    250,
    106
  ],
  [
    "03163C",
    "Tangaroa",
    3,
    22,
    60,
    155,
    230,
    31
  ],
  [
    "032B52",
    "Green Vogue",
    3,
    43,
    82,
    148,
    236,
    42
  ],
  [
    "036A6E",
    "Mosque",
    3,
    106,
    110,
    129,
    241,
    56
  ],
  [
    "041004",
    "Midnight Moss",
    4,
    16,
    4,
    85,
    153,
    10
  ],
  [
    "041322",
    "Black Pearl",
    4,
    19,
    34,
    148,
    201,
    19
  ],
  [
    "042E4C",
    "Blue Whale",
    4,
    46,
    76,
    145,
    229,
    40
  ],
  [
    "044022",
    "Zuccini",
    4,
    64,
    34,
    106,
    225,
    34
  ],
  [
    "044259",
    "Teal Blue",
    4,
    66,
    89,
    139,
    233,
    46
  ],
  [
    "051040",
    "Deep Cove",
    5,
    16,
    64,
    162,
    218,
    34
  ],
  [
    "051657",
    "Gulf Blue",
    5,
    22,
    87,
    161,
    227,
    46
  ],
  [
    "055989",
    "Venice Blue",
    5,
    89,
    137,
    142,
    237,
    71
  ],
  [
    "056F57",
    "Watercourse",
    5,
    111,
    87,
    117,
    233,
    58
  ],
  [
    "062A78",
    "Catalina Blue",
    6,
    42,
    120,
    156,
    230,
    63
  ],
  [
    "063537",
    "Tiber",
    6,
    53,
    55,
    129,
    204,
    30
  ],
  [
    "069B81",
    "Gossamer",
    6,
    155,
    129,
    120,
    235,
    80
  ],
  [
    "06A189",
    "Niagara",
    6,
    161,
    137,
    120,
    236,
    83
  ],
  [
    "073A50",
    "Tarawera",
    7,
    58,
    80,
    140,
    213,
    43
  ],
  [
    "080110",
    "Jaguar",
    8,
    1,
    16,
    189,
    225,
    8
  ],
  [
    "081910",
    "Black Bean",
    8,
    25,
    16,
    105,
    131,
    16
  ],
  [
    "082567",
    "Deep Sapphire",
    8,
    37,
    103,
    157,
    218,
    55
  ],
  [
    "088370",
    "Elf Green",
    8,
    131,
    112,
    120,
    225,
    69
  ],
  [
    "08E8DE",
    "Bright Turquoise",
    8,
    232,
    222,
    125,
    238,
    120
  ],
  [
    "092256",
    "Downriver",
    9,
    34,
    86,
    156,
    206,
    47
  ],
  [
    "09230F",
    "Palm Green",
    9,
    35,
    15,
    94,
    150,
    22
  ],
  [
    "09255D",
    "Madison",
    9,
    37,
    93,
    155,
    210,
    50
  ],
  [
    "093624",
    "Bottle Green",
    9,
    54,
    36,
    110,
    182,
    31
  ],
  [
    "095859",
    "Deep Sea Green",
    9,
    88,
    89,
    128,
    208,
    48
  ],
  [
    "097F4B",
    "Salem",
    9,
    127,
    75,
    108,
    221,
    68
  ],
  [
    "0A001C",
    "Black Russian",
    10,
    0,
    28,
    185,
    255,
    14
  ],
  [
    "0A480D",
    "Dark Fern",
    10,
    72,
    13,
    87,
    192,
    40
  ],
  [
    "0A6906",
    "Japanese Laurel",
    10,
    105,
    6,
    83,
    227,
    55
  ],
  [
    "0A6F75",
    "Atoll",
    10,
    111,
    117,
    129,
    214,
    63
  ],
  [
    "0B0B0B",
    "Cod Gray",
    11,
    11,
    11,
    0,
    0,
    11
  ],
  [
    "0B0F08",
    "Marshland",
    11,
    15,
    8,
    66,
    77,
    11
  ],
  [
    "0B1107",
    "Gordons Green",
    11,
    17,
    7,
    68,
    106,
    12
  ],
  [
    "0B1304",
    "Black Forest",
    11,
    19,
    4,
    65,
    166,
    11
  ],
  [
    "0B6207",
    "San Felix",
    11,
    98,
    7,
    83,
    220,
    52
  ],
  [
    "0BDA51",
    "Malachite",
    11,
    218,
    81,
    99,
    230,
    114
  ],
  [
    "0C0B1D",
    "Ebony",
    12,
    11,
    29,
    172,
    114,
    20
  ],
  [
    "0C0D0F",
    "Woodsmoke",
    12,
    13,
    15,
    155,
    28,
    13
  ],
  [
    "0C1911",
    "Racing Green",
    12,
    25,
    17,
    101,
    89,
    18
  ],
  [
    "0C7A79",
    "Surfie Green",
    12,
    122,
    121,
    127,
    209,
    67
  ],
  [
    "0C8990",
    "Blue Chill",
    12,
    137,
    144,
    129,
    215,
    78
  ],
  [
    "0D0332",
    "Black Rock",
    13,
    3,
    50,
    179,
    226,
    26
  ],
  [
    "0D1117",
    "Bunker",
    13,
    17,
    23,
    153,
    70,
    18
  ],
  [
    "0D1C19",
    "Aztec",
    13,
    28,
    25,
    118,
    93,
    20
  ],
  [
    "0D2E1C",
    "Bush",
    13,
    46,
    28,
    104,
    142,
    29
  ],
  [
    "0E0E18",
    "Cinder",
    14,
    14,
    24,
    170,
    67,
    19
  ],
  [
    "0E2A30",
    "Firefly",
    14,
    42,
    48,
    135,
    139,
    31
  ],
  [
    "0F2D9E",
    "Torea Bay",
    15,
    45,
    158,
    161,
    210,
    86
  ],
  [
    "10121D",
    "Vulcan",
    16,
    18,
    29,
    163,
    73,
    22
  ],
  [
    "101405",
    "Green Waterloo",
    16,
    20,
    5,
    53,
    153,
    12
  ],
  [
    "105852",
    "Eden",
    16,
    88,
    82,
    123,
    176,
    52
  ],
  [
    "110C6C",
    "Arapawa",
    17,
    12,
    108,
    172,
    204,
    60
  ],
  [
    "120A8F",
    "Ultramarine",
    18,
    10,
    143,
    172,
    221,
    76
  ],
  [
    "123447",
    "Elephant",
    18,
    52,
    71,
    142,
    151,
    44
  ],
  [
    "126B40",
    "Jewel",
    18,
    107,
    64,
    106,
    181,
    62
  ],
  [
    "130000",
    "Diesel",
    19,
    0,
    0,
    0,
    255,
    9
  ],
  [
    "130A06",
    "Asphalt",
    19,
    10,
    6,
    13,
    132,
    12
  ],
  [
    "13264D",
    "Blue Zodiac",
    19,
    38,
    77,
    156,
    154,
    48
  ],
  [
    "134F19",
    "Parsley",
    19,
    79,
    25,
    89,
    156,
    49
  ],
  [
    "140600",
    "Nero",
    20,
    6,
    0,
    12,
    255,
    10
  ],
  [
    "1450AA",
    "Tory Blue",
    20,
    80,
    170,
    153,
    201,
    95
  ],
  [
    "151F4C",
    "Bunting",
    21,
    31,
    76,
    162,
    144,
    48
  ],
  [
    "1560BD",
    "Denim",
    21,
    96,
    189,
    151,
    203,
    105
  ],
  [
    "15736B",
    "Genoa",
    21,
    115,
    107,
    123,
    176,
    68
  ],
  [
    "161928",
    "Mirage",
    22,
    25,
    40,
    162,
    74,
    31
  ],
  [
    "161D10",
    "Hunter Green",
    22,
    29,
    16,
    65,
    73,
    22
  ],
  [
    "162A40",
    "Big Stone",
    22,
    42,
    64,
    149,
    124,
    43
  ],
  [
    "163222",
    "Celtic",
    22,
    50,
    34,
    103,
    99,
    36
  ],
  [
    "16322C",
    "Timber Green",
    22,
    50,
    44,
    118,
    99,
    36
  ],
  [
    "163531",
    "Gable Green",
    22,
    53,
    49,
    122,
    105,
    37
  ],
  [
    "171F04",
    "Pine Tree",
    23,
    31,
    4,
    55,
    196,
    17
  ],
  [
    "175579",
    "Chathams Blue",
    23,
    85,
    121,
    143,
    173,
    72
  ],
  [
    "182D09",
    "Deep Forest Green",
    24,
    45,
    9,
    67,
    170,
    27
  ],
  [
    "18587A",
    "Blumine",
    24,
    88,
    122,
    142,
    171,
    73
  ],
  [
    "19330E",
    "Palm Leaf",
    25,
    51,
    14,
    72,
    145,
    32
  ],
  [
    "193751",
    "Nile Blue",
    25,
    55,
    81,
    147,
    134,
    52
  ],
  [
    "1959A8",
    "Fun Blue",
    25,
    89,
    168,
    150,
    188,
    96
  ],
  [
    "1A1A68",
    "Lucky Point",
    26,
    26,
    104,
    170,
    153,
    65
  ],
  [
    "1AB385",
    "Mountain Meadow",
    26,
    179,
    133,
    114,
    190,
    102
  ],
  [
    "1B0245",
    "Tolopea",
    27,
    2,
    69,
    185,
    240,
    35
  ],
  [
    "1B1035",
    "Haiti",
    27,
    16,
    53,
    182,
    136,
    34
  ],
  [
    "1B127B",
    "Deep Koamaru",
    27,
    18,
    123,
    173,
    189,
    70
  ],
  [
    "1B1404",
    "Acadia",
    27,
    20,
    4,
    29,
    189,
    15
  ],
  [
    "1B2F11",
    "Seaweed",
    27,
    47,
    17,
    70,
    119,
    32
  ],
  [
    "1B3162",
    "Biscay",
    27,
    49,
    98,
    156,
    144,
    62
  ],
  [
    "1B659D",
    "Matisse",
    27,
    101,
    157,
    145,
    180,
    92
  ],
  [
    "1C1208",
    "Crowshead",
    28,
    18,
    8,
    21,
    141,
    18
  ],
  [
    "1C1E13",
    "Rangoon Green",
    28,
    30,
    19,
    50,
    57,
    24
  ],
  [
    "1C39BB",
    "Persian Blue",
    28,
    57,
    187,
    162,
    188,
    107
  ],
  [
    "1C402E",
    "Everglade",
    28,
    64,
    46,
    106,
    99,
    46
  ],
  [
    "1C7C7D",
    "Elm",
    28,
    124,
    125,
    127,
    161,
    76
  ],
  [
    "1D6142",
    "Green Pea",
    29,
    97,
    66,
    108,
    137,
    62
  ],
  [
    "1E0F04",
    "Creole",
    30,
    15,
    4,
    17,
    195,
    17
  ],
  [
    "1E1609",
    "Karaka",
    30,
    22,
    9,
    26,
    137,
    19
  ],
  [
    "1E1708",
    "El Paso",
    30,
    23,
    8,
    28,
    147,
    19
  ],
  [
    "1E385B",
    "Cello",
    30,
    56,
    91,
    151,
    128,
    60
  ],
  [
    "1E433C",
    "Te Papa Green",
    30,
    67,
    60,
    119,
    97,
    48
  ],
  [
    "1E90FF",
    "Dodger Blue",
    30,
    144,
    255,
    148,
    255,
    142
  ],
  [
    "1E9AB0",
    "Eastern Blue",
    30,
    154,
    176,
    133,
    180,
    103
  ],
  [
    "1F120F",
    "Night Rider",
    31,
    18,
    15,
    7,
    88,
    23
  ],
  [
    "1FC2C2",
    "Java",
    31,
    194,
    194,
    127,
    184,
    112
  ],
  [
    "20208D",
    "Jacksons Purple",
    32,
    32,
    141,
    170,
    160,
    86
  ],
  [
    "202E54",
    "Cloud Burst",
    32,
    46,
    84,
    158,
    114,
    58
  ],
  [
    "204852",
    "Blue Dianne",
    32,
    72,
    82,
    136,
    111,
    57
  ],
  [
    "211A0E",
    "Eternity",
    33,
    26,
    14,
    26,
    103,
    23
  ],
  [
    "220878",
    "Deep Blue",
    34,
    8,
    120,
    179,
    223,
    64
  ],
  [
    "228B22",
    "Forest Green",
    34,
    139,
    34,
    85,
    154,
    86
  ],
  [
    "233418",
    "Mallard",
    35,
    52,
    24,
    68,
    93,
    38
  ],
  [
    "240A40",
    "Violet",
    36,
    10,
    64,
    190,
    186,
    36
  ],
  [
    "240C02",
    "Kilamanjaro",
    36,
    12,
    2,
    12,
    228,
    19
  ],
  [
    "242A1D",
    "Log Cabin",
    36,
    42,
    29,
    62,
    46,
    35
  ],
  [
    "242E16",
    "Black Olive",
    36,
    46,
    22,
    60,
    90,
    34
  ],
  [
    "24500F",
    "Green House",
    36,
    80,
    15,
    71,
    174,
    47
  ],
  [
    "251607",
    "Graphite",
    37,
    22,
    7,
    21,
    173,
    22
  ],
  [
    "251706",
    "Cannon Black",
    37,
    23,
    6,
    23,
    183,
    21
  ],
  [
    "251F4F",
    "Port Gore",
    37,
    31,
    79,
    175,
    111,
    55
  ],
  [
    "25272C",
    "Shark",
    37,
    39,
    44,
    157,
    22,
    40
  ],
  [
    "25311C",
    "Green Kelp",
    37,
    49,
    28,
    66,
    69,
    38
  ],
  [
    "2596D1",
    "Curious Blue",
    37,
    150,
    209,
    142,
    178,
    123
  ],
  [
    "260368",
    "Paua",
    38,
    3,
    104,
    184,
    240,
    53
  ],
  [
    "26056A",
    "Paris M",
    38,
    5,
    106,
    183,
    232,
    55
  ],
  [
    "261105",
    "Wood Bark",
    38,
    17,
    5,
    15,
    195,
    21
  ],
  [
    "261414",
    "Gondola",
    38,
    20,
    20,
    0,
    79,
    29
  ],
  [
    "262335",
    "Steel Gray",
    38,
    35,
    53,
    177,
    52,
    44
  ],
  [
    "26283B",
    "Ebony Clay",
    38,
    40,
    59,
    165,
    55,
    48
  ],
  [
    "273A81",
    "Bay of Many",
    39,
    58,
    129,
    161,
    136,
    84
  ],
  [
    "27504B",
    "Plantation",
    39,
    80,
    75,
    122,
    87,
    59
  ],
  [
    "278A5B",
    "Eucalyptus",
    39,
    138,
    91,
    107,
    142,
    88
  ],
  [
    "281E15",
    "Oil",
    40,
    30,
    21,
    20,
    79,
    30
  ],
  [
    "283A77",
    "Astronaut",
    40,
    58,
    119,
    160,
    126,
    79
  ],
  [
    "286ACD",
    "Mariner",
    40,
    106,
    205,
    153,
    171,
    122
  ],
  [
    "290C5E",
    "Violent Violet",
    41,
    12,
    94,
    185,
    197,
    53
  ],
  [
    "292130",
    "Bastille",
    41,
    33,
    48,
    192,
    47,
    40
  ],
  [
    "292319",
    "Zeus",
    41,
    35,
    25,
    26,
    61,
    33
  ],
  [
    "292937",
    "Charade",
    41,
    41,
    55,
    170,
    37,
    48
  ],
  [
    "297B9A",
    "Jelly Bean",
    41,
    123,
    154,
    139,
    147,
    97
  ],
  [
    "29AB87",
    "Jungle Green",
    41,
    171,
    135,
    115,
    156,
    105
  ],
  [
    "2A0359",
    "Cherry Pie",
    42,
    3,
    89,
    189,
    238,
    46
  ],
  [
    "2A140E",
    "Coffee Bean",
    42,
    20,
    14,
    9,
    127,
    28
  ],
  [
    "2A2630",
    "Baltic Sea",
    42,
    38,
    48,
    187,
    29,
    43
  ],
  [
    "2A380B",
    "Turtle Green",
    42,
    56,
    11,
    55,
    171,
    33
  ],
  [
    "2A52BE",
    "Cerulean Blue",
    42,
    82,
    190,
    158,
    162,
    116
  ],
  [
    "2B0202",
    "Sepia Black",
    43,
    2,
    2,
    0,
    232,
    22
  ],
  [
    "2B194F",
    "Valhalla",
    43,
    25,
    79,
    184,
    132,
    52
  ],
  [
    "2B3228",
    "Heavy Metal",
    43,
    50,
    40,
    72,
    28,
    44
  ],
  [
    "2C0E8C",
    "Blue Gem",
    44,
    14,
    140,
    180,
    208,
    77
  ],
  [
    "2C1632",
    "Revolver",
    44,
    22,
    50,
    203,
    99,
    36
  ],
  [
    "2C2133",
    "Bleached Cedar",
    44,
    33,
    51,
    195,
    54,
    42
  ],
  [
    "2C8C84",
    "Lochinvar",
    44,
    140,
    132,
    123,
    133,
    92
  ],
  [
    "2D2510",
    "Mikado",
    45,
    37,
    16,
    30,
    121,
    30
  ],
  [
    "2D383A",
    "Outer Space",
    45,
    56,
    58,
    134,
    32,
    51
  ],
  [
    "2D569B",
    "St Tropaz",
    45,
    86,
    155,
    154,
    140,
    100
  ],
  [
    "2E0329",
    "Jacaranda",
    46,
    3,
    41,
    -37,
    223,
    24
  ],
  [
    "2E1905",
    "Jacko Bean",
    46,
    25,
    5,
    20,
    204,
    25
  ],
  [
    "2E3222",
    "Rangitoto",
    46,
    50,
    34,
    53,
    48,
    42
  ],
  [
    "2E3F62",
    "Rhino",
    46,
    63,
    98,
    156,
    92,
    72
  ],
  [
    "2E8B57",
    "Sea Green",
    46,
    139,
    87,
    103,
    128,
    92
  ],
  [
    "2EBFD4",
    "Scooter",
    46,
    191,
    212,
    132,
    167,
    129
  ],
  [
    "2F270E",
    "Onion",
    47,
    39,
    14,
    32,
    137,
    30
  ],
  [
    "2F3CB3",
    "Governor Bay",
    47,
    60,
    179,
    165,
    148,
    113
  ],
  [
    "2F519E",
    "Sapphire",
    47,
    81,
    158,
    156,
    138,
    102
  ],
  [
    "2F5A57",
    "Spectra",
    47,
    90,
    87,
    124,
    80,
    68
  ],
  [
    "2F6168",
    "Casal",
    47,
    97,
    104,
    132,
    96,
    75
  ],
  [
    "300529",
    "Melanzane",
    48,
    5,
    41,
    -35,
    206,
    26
  ],
  [
    "301F1E",
    "Cocoa Brown",
    48,
    31,
    30,
    2,
    58,
    39
  ],
  [
    "302A0F",
    "Woodrush",
    48,
    42,
    15,
    34,
    133,
    31
  ],
  [
    "304B6A",
    "San Juan",
    48,
    75,
    106,
    150,
    96,
    77
  ],
  [
    "30D5C8",
    "Turquoise",
    48,
    213,
    200,
    124,
    168,
    130
  ],
  [
    "311C17",
    "Eclipse",
    49,
    28,
    23,
    8,
    92,
    36
  ],
  [
    "314459",
    "Pickled Bluewood",
    49,
    68,
    89,
    149,
    73,
    69
  ],
  [
    "315BA1",
    "Azure",
    49,
    91,
    161,
    154,
    136,
    105
  ],
  [
    "31728D",
    "Calypso",
    49,
    114,
    141,
    139,
    123,
    95
  ],
  [
    "317D82",
    "Paradiso",
    49,
    125,
    130,
    130,
    115,
    89
  ],
  [
    "32127A",
    "Persian Indigo",
    50,
    18,
    122,
    183,
    189,
    70
  ],
  [
    "32293A",
    "Blackcurrant",
    50,
    41,
    58,
    192,
    43,
    49
  ],
  [
    "323232",
    "Mine Shaft",
    50,
    50,
    50,
    0,
    0,
    50
  ],
  [
    "325D52",
    "Stromboli",
    50,
    93,
    82,
    116,
    76,
    71
  ],
  [
    "327C14",
    "Bilbao",
    50,
    124,
    20,
    72,
    184,
    72
  ],
  [
    "327DA0",
    "Astral",
    50,
    125,
    160,
    141,
    133,
    105
  ],
  [
    "33036B",
    "Christalle",
    51,
    3,
    107,
    189,
    241,
    55
  ],
  [
    "33292F",
    "Thunder",
    51,
    41,
    47,
    -25,
    27,
    46
  ],
  [
    "33CC99",
    "Shamrock",
    51,
    204,
    153,
    113,
    153,
    127
  ],
  [
    "341515",
    "Tamarind",
    52,
    21,
    21,
    0,
    108,
    36
  ],
  [
    "350036",
    "Mardi Gras",
    53,
    0,
    54,
    211,
    255,
    27
  ],
  [
    "350E42",
    "Valentino",
    53,
    14,
    66,
    201,
    165,
    40
  ],
  [
    "350E57",
    "Jagger",
    53,
    14,
    87,
    192,
    184,
    50
  ],
  [
    "353542",
    "Tuna",
    53,
    53,
    66,
    170,
    27,
    59
  ],
  [
    "354E8C",
    "Chambray",
    53,
    78,
    140,
    157,
    114,
    96
  ],
  [
    "363050",
    "Martinique",
    54,
    48,
    80,
    177,
    63,
    64
  ],
  [
    "363534",
    "Tuatara",
    54,
    53,
    52,
    21,
    4,
    52
  ],
  [
    "363C0D",
    "Waiouru",
    54,
    60,
    13,
    47,
    164,
    36
  ],
  [
    "36747D",
    "Ming",
    54,
    116,
    125,
    132,
    101,
    89
  ],
  [
    "368716",
    "La Palma",
    54,
    135,
    22,
    72,
    183,
    78
  ],
  [
    "370202",
    "Chocolate",
    55,
    2,
    2,
    0,
    237,
    28
  ],
  [
    "371D09",
    "Clinker",
    55,
    29,
    9,
    18,
    183,
    32
  ],
  [
    "37290E",
    "Brown Tumbleweed",
    55,
    41,
    14,
    27,
    151,
    34
  ],
  [
    "373021",
    "Birch",
    55,
    48,
    33,
    28,
    63,
    44
  ],
  [
    "377475",
    "Oracle",
    55,
    116,
    117,
    128,
    91,
    86
  ],
  [
    "380474",
    "Blue Diamond",
    56,
    4,
    116,
    189,
    238,
    60
  ],
  [
    "381A51",
    "Grape",
    56,
    26,
    81,
    193,
    131,
    53
  ],
  [
    "383533",
    "Dune",
    56,
    53,
    51,
    17,
    11,
    53
  ],
  [
    "384555",
    "Oxford Blue",
    56,
    69,
    85,
    150,
    52,
    70
  ],
  [
    "384910",
    "Clover",
    56,
    73,
    16,
    55,
    163,
    44
  ],
  [
    "394851",
    "Limed Spruce",
    57,
    72,
    81,
    143,
    44,
    69
  ],
  [
    "396413",
    "Dell",
    57,
    100,
    19,
    65,
    173,
    59
  ],
  [
    "3A0020",
    "Toledo",
    58,
    0,
    32,
    -23,
    255,
    29
  ],
  [
    "3A2010",
    "Sambuca",
    58,
    32,
    16,
    16,
    144,
    36
  ],
  [
    "3A2A6A",
    "Jacarta",
    58,
    42,
    106,
    180,
    110,
    74
  ],
  [
    "3A686C",
    "William",
    58,
    104,
    108,
    130,
    76,
    83
  ],
  [
    "3A6A47",
    "Killarney",
    58,
    106,
    71,
    96,
    74,
    82
  ],
  [
    "3AB09E",
    "Keppel",
    58,
    176,
    158,
    121,
    128,
    117
  ],
  [
    "3B000B",
    "Temptress",
    59,
    0,
    11,
    -7,
    255,
    29
  ],
  [
    "3B0910",
    "Aubergine",
    59,
    9,
    16,
    -5,
    187,
    34
  ],
  [
    "3B1F1F",
    "Jon",
    59,
    31,
    31,
    0,
    79,
    45
  ],
  [
    "3B2820",
    "Treehouse",
    59,
    40,
    32,
    12,
    75,
    45
  ],
  [
    "3B7A57",
    "Amazon",
    59,
    122,
    87,
    103,
    88,
    90
  ],
  [
    "3B91B4",
    "Boston Blue",
    59,
    145,
    180,
    139,
    129,
    119
  ],
  [
    "3C0878",
    "Windsor",
    60,
    8,
    120,
    189,
    223,
    64
  ],
  [
    "3C1206",
    "Rebel",
    60,
    18,
    6,
    9,
    208,
    32
  ],
  [
    "3C1F76",
    "Meteorite",
    60,
    31,
    118,
    184,
    148,
    74
  ],
  [
    "3C2005",
    "Dark Ebony",
    60,
    32,
    5,
    20,
    215,
    32
  ],
  [
    "3C3910",
    "Camouflage",
    60,
    57,
    16,
    39,
    147,
    38
  ],
  [
    "3C4151",
    "Bright Gray",
    60,
    65,
    81,
    159,
    37,
    70
  ],
  [
    "3C4443",
    "Cape Cod",
    60,
    68,
    67,
    122,
    15,
    64
  ],
  [
    "3C493A",
    "Lunar Green",
    60,
    73,
    58,
    79,
    29,
    65
  ],
  [
    "3D0C02",
    "Bean  ",
    61,
    12,
    2,
    7,
    238,
    31
  ],
  [
    "3D2B1F",
    "Bistre",
    61,
    43,
    31,
    17,
    83,
    46
  ],
  [
    "3D7D52",
    "Goblin",
    61,
    125,
    82,
    98,
    87,
    93
  ],
  [
    "3E0480",
    "Kingfisher Daisy",
    62,
    4,
    128,
    189,
    239,
    65
  ],
  [
    "3E1C14",
    "Cedar",
    62,
    28,
    20,
    8,
    130,
    40
  ],
  [
    "3E2B23",
    "English Walnut",
    62,
    43,
    35,
    12,
    70,
    48
  ],
  [
    "3E2C1C",
    "Black Marlin",
    62,
    44,
    28,
    20,
    96,
    44
  ],
  [
    "3E3A44",
    "Ship Gray",
    62,
    58,
    68,
    187,
    20,
    63
  ],
  [
    "3EABBF",
    "Pelorous",
    62,
    171,
    191,
    134,
    130,
    126
  ],
  [
    "3F2109",
    "Bronze",
    63,
    33,
    9,
    18,
    191,
    36
  ],
  [
    "3F2500",
    "Cola",
    63,
    37,
    0,
    24,
    255,
    31
  ],
  [
    "3F3002",
    "Madras",
    63,
    48,
    2,
    32,
    239,
    32
  ],
  [
    "3F307F",
    "Minsk",
    63,
    48,
    127,
    178,
    115,
    87
  ],
  [
    "3F4C3A",
    "Cabbage Pont",
    63,
    76,
    58,
    73,
    34,
    67
  ],
  [
    "3F583B",
    "Tom Thumb",
    63,
    88,
    59,
    79,
    50,
    73
  ],
  [
    "3F5D53",
    "Mineral Green",
    63,
    93,
    83,
    113,
    49,
    78
  ],
  [
    "3FC1AA",
    "Puerto Rico",
    63,
    193,
    170,
    119,
    130,
    128
  ],
  [
    "3FFF00",
    "Harlequin",
    63,
    255,
    0,
    74,
    255,
    127
  ],
  [
    "401801",
    "Brown Pod",
    64,
    24,
    1,
    15,
    247,
    32
  ],
  [
    "40291D",
    "Cork",
    64,
    41,
    29,
    14,
    95,
    46
  ],
  [
    "403B38",
    "Masala",
    64,
    59,
    56,
    15,
    17,
    60
  ],
  [
    "403D19",
    "Thatch Green",
    64,
    61,
    25,
    39,
    111,
    44
  ],
  [
    "405169",
    "Fiord",
    64,
    81,
    105,
    152,
    61,
    84
  ],
  [
    "40826D",
    "Viridian",
    64,
    130,
    109,
    113,
    86,
    97
  ],
  [
    "40A860",
    "Chateau Green",
    64,
    168,
    96,
    98,
    114,
    116
  ],
  [
    "410056",
    "Ripe Plum",
    65,
    0,
    86,
    202,
    255,
    43
  ],
  [
    "411F10",
    "Paco",
    65,
    31,
    16,
    13,
    154,
    40
  ],
  [
    "412010",
    "Deep Oak",
    65,
    32,
    16,
    13,
    154,
    40
  ],
  [
    "413C37",
    "Merlin",
    65,
    60,
    55,
    21,
    21,
    60
  ],
  [
    "414257",
    "Gun Powder",
    65,
    66,
    87,
    168,
    36,
    76
  ],
  [
    "414C7D",
    "East Bay",
    65,
    76,
    125,
    162,
    80,
    95
  ],
  [
    "4169E1",
    "Royal Blue",
    65,
    105,
    225,
    159,
    185,
    145
  ],
  [
    "41AA78",
    "Ocean Green",
    65,
    170,
    120,
    107,
    113,
    117
  ],
  [
    "420303",
    "Burnt Maroon",
    66,
    3,
    3,
    0,
    232,
    34
  ],
  [
    "423921",
    "Lisbon Brown",
    66,
    57,
    33,
    30,
    85,
    49
  ],
  [
    "427977",
    "Faded Jade",
    66,
    121,
    119,
    125,
    74,
    93
  ],
  [
    "431560",
    "Scarlet Gum",
    67,
    21,
    96,
    196,
    163,
    58
  ],
  [
    "433120",
    "Iroko",
    67,
    49,
    32,
    20,
    90,
    49
  ],
  [
    "433E37",
    "Armadillo",
    67,
    62,
    55,
    24,
    25,
    61
  ],
  [
    "434C59",
    "River Bed",
    67,
    76,
    89,
    152,
    35,
    78
  ],
  [
    "436A0D",
    "Green Leaf",
    67,
    106,
    13,
    60,
    199,
    59
  ],
  [
    "44012D",
    "Barossa",
    68,
    1,
    45,
    -27,
    247,
    34
  ],
  [
    "441D00",
    "Morocco Brown",
    68,
    29,
    0,
    18,
    255,
    34
  ],
  [
    "444954",
    "Mako",
    68,
    73,
    84,
    156,
    26,
    76
  ],
  [
    "454936",
    "Kelp",
    69,
    73,
    54,
    51,
    38,
    63
  ],
  [
    "456CAC",
    "San Marino",
    69,
    108,
    172,
    153,
    108,
    120
  ],
  [
    "45B1E8",
    "Picton Blue",
    69,
    177,
    232,
    141,
    198,
    150
  ],
  [
    "460B41",
    "Loulou",
    70,
    11,
    65,
    -38,
    185,
    40
  ],
  [
    "462425",
    "Crater Brown",
    70,
    36,
    37,
    -1,
    81,
    53
  ],
  [
    "465945",
    "Gray Asparagus",
    70,
    89,
    69,
    82,
    32,
    79
  ],
  [
    "4682B4",
    "Steel Blue",
    70,
    130,
    180,
    146,
    112,
    125
  ],
  [
    "480404",
    "Rustic Red",
    72,
    4,
    4,
    0,
    228,
    38
  ],
  [
    "480607",
    "Bulgarian Rose",
    72,
    6,
    7,
    0,
    215,
    39
  ],
  [
    "480656",
    "Clairvoyant",
    72,
    6,
    86,
    205,
    221,
    46
  ],
  [
    "481C1C",
    "Cocoa Bean",
    72,
    28,
    28,
    0,
    112,
    50
  ],
  [
    "483131",
    "Woody Brown",
    72,
    49,
    49,
    0,
    48,
    60
  ],
  [
    "483C32",
    "Taupe",
    72,
    60,
    50,
    19,
    45,
    60
  ],
  [
    "49170C",
    "Van Cleef",
    73,
    23,
    12,
    7,
    183,
    42
  ],
  [
    "492615",
    "Brown Derby",
    73,
    38,
    21,
    13,
    141,
    46
  ],
  [
    "49371B",
    "Metallic Bronze",
    73,
    55,
    27,
    25,
    117,
    50
  ],
  [
    "495400",
    "Verdun Green",
    73,
    84,
    0,
    48,
    255,
    42
  ],
  [
    "496679",
    "Blue Bayoux",
    73,
    102,
    121,
    144,
    63,
    97
  ],
  [
    "497183",
    "Bismark",
    73,
    113,
    131,
    140,
    72,
    101
  ],
  [
    "4A2A04",
    "Bracken",
    74,
    42,
    4,
    23,
    228,
    39
  ],
  [
    "4A3004",
    "Deep Bronze",
    74,
    48,
    4,
    26,
    228,
    39
  ],
  [
    "4A3C30",
    "Mondo",
    74,
    60,
    48,
    19,
    54,
    61
  ],
  [
    "4A4244",
    "Tundora",
    74,
    66,
    68,
    -10,
    14,
    70
  ],
  [
    "4A444B",
    "Gravel",
    74,
    68,
    75,
    206,
    12,
    71
  ],
  [
    "4A4E5A",
    "Trout",
    74,
    78,
    90,
    159,
    24,
    82
  ],
  [
    "4B0082",
    "Pigment Indigo",
    75,
    0,
    130,
    194,
    255,
    65
  ],
  [
    "4B5D52",
    "Nandor",
    75,
    93,
    82,
    101,
    27,
    84
  ],
  [
    "4C3024",
    "Saddle",
    76,
    48,
    36,
    12,
    91,
    56
  ],
  [
    "4C4F56",
    "Abbey",
    76,
    79,
    86,
    157,
    15,
    81
  ],
  [
    "4D0135",
    "Blackberry",
    77,
    1,
    53,
    -29,
    248,
    38
  ],
  [
    "4D0A18",
    "Cab Sav",
    77,
    10,
    24,
    -8,
    196,
    43
  ],
  [
    "4D1E01",
    "Indian Tan",
    77,
    30,
    1,
    16,
    248,
    38
  ],
  [
    "4D282D",
    "Cowboy",
    77,
    40,
    45,
    -5,
    80,
    58
  ],
  [
    "4D282E",
    "Livid Brown",
    77,
    40,
    46,
    -6,
    80,
    58
  ],
  [
    "4D3833",
    "Rock",
    77,
    56,
    51,
    8,
    51,
    64
  ],
  [
    "4D3D14",
    "Punga",
    77,
    61,
    20,
    30,
    149,
    48
  ],
  [
    "4D400F",
    "Bronzetone",
    77,
    64,
    15,
    33,
    171,
    46
  ],
  [
    "4D5328",
    "Woodland",
    77,
    83,
    40,
    48,
    89,
    61
  ],
  [
    "4E0606",
    "Mahogany",
    78,
    6,
    6,
    0,
    218,
    42
  ],
  [
    "4E2A5A",
    "Bossanova",
    78,
    42,
    90,
    201,
    92,
    66
  ],
  [
    "4E3B41",
    "Matterhorn",
    78,
    59,
    65,
    -13,
    35,
    68
  ],
  [
    "4E420C",
    "Bronze Olive",
    78,
    66,
    12,
    34,
    187,
    45
  ],
  [
    "4E4562",
    "Mulled Wine",
    78,
    69,
    98,
    183,
    44,
    83
  ],
  [
    "4E6649",
    "Axolotl",
    78,
    102,
    73,
    77,
    42,
    87
  ],
  [
    "4E7F9E",
    "Wedgewood",
    78,
    127,
    158,
    143,
    86,
    118
  ],
  [
    "4EABD1",
    "Shakespeare",
    78,
    171,
    209,
    139,
    149,
    143
  ],
  [
    "4F1C70",
    "Honey Flower",
    79,
    28,
    112,
    195,
    153,
    70
  ],
  [
    "4F2398",
    "Daisy Bush",
    79,
    35,
    152,
    185,
    159,
    93
  ],
  [
    "4F69C6",
    "Indigo",
    79,
    105,
    198,
    160,
    130,
    138
  ],
  [
    "4F7942",
    "Fern Green",
    79,
    121,
    66,
    74,
    74,
    93
  ],
  [
    "4F9D5D",
    "Fruit Salad",
    79,
    157,
    93,
    92,
    84,
    118
  ],
  [
    "4FA83D",
    "Apple",
    79,
    168,
    61,
    77,
    119,
    114
  ],
  [
    "504351",
    "Mortar",
    80,
    67,
    81,
    209,
    24,
    73
  ],
  [
    "507096",
    "Kashmir Blue",
    80,
    112,
    150,
    150,
    77,
    115
  ],
  [
    "507672",
    "Cutty Sark",
    80,
    118,
    114,
    123,
    48,
    99
  ],
  [
    "50C878",
    "Emerald",
    80,
    200,
    120,
    99,
    133,
    140
  ],
  [
    "514649",
    "Emperor",
    81,
    70,
    73,
    -11,
    18,
    75
  ],
  [
    "516E3D",
    "Chalet Green",
    81,
    110,
    61,
    67,
    73,
    85
  ],
  [
    "517C66",
    "Como",
    81,
    124,
    102,
    105,
    53,
    102
  ],
  [
    "51808F",
    "Smalt Blue",
    81,
    128,
    143,
    137,
    70,
    112
  ],
  [
    "52001F",
    "Castro",
    82,
    0,
    31,
    -16,
    255,
    41
  ],
  [
    "520C17",
    "Maroon Oak",
    82,
    12,
    23,
    -6,
    189,
    47
  ],
  [
    "523C94",
    "Gigas",
    82,
    60,
    148,
    180,
    107,
    104
  ],
  [
    "533455",
    "Voodoo",
    83,
    52,
    85,
    209,
    61,
    68
  ],
  [
    "534491",
    "Victoria",
    83,
    68,
    145,
    178,
    92,
    106
  ],
  [
    "53824B",
    "Hippie Green",
    83,
    130,
    75,
    78,
    68,
    102
  ],
  [
    "541012",
    "Heath",
    84,
    16,
    18,
    -1,
    173,
    50
  ],
  [
    "544333",
    "Judge Gray",
    84,
    67,
    51,
    20,
    62,
    67
  ],
  [
    "54534D",
    "Fuscous Gray",
    84,
    83,
    77,
    36,
    11,
    80
  ],
  [
    "549019",
    "Vida Loca",
    84,
    144,
    25,
    63,
    179,
    84
  ],
  [
    "55280C",
    "Cioccolato",
    85,
    40,
    12,
    16,
    191,
    48
  ],
  [
    "555B10",
    "Saratoga",
    85,
    91,
    16,
    45,
    178,
    53
  ],
  [
    "556D56",
    "Finlandia",
    85,
    109,
    86,
    86,
    31,
    97
  ],
  [
    "5590D9",
    "Havelock Blue",
    85,
    144,
    217,
    151,
    161,
    151
  ],
  [
    "56B4BE",
    "Fountain Blue",
    86,
    180,
    190,
    131,
    113,
    138
  ],
  [
    "578363",
    "Spring Leaves",
    87,
    131,
    99,
    96,
    51,
    109
  ],
  [
    "583401",
    "Saddle Brown",
    88,
    52,
    1,
    24,
    249,
    44
  ],
  [
    "585562",
    "Scarpa Flow",
    88,
    85,
    98,
    179,
    18,
    91
  ],
  [
    "587156",
    "Cactus",
    88,
    113,
    86,
    81,
    34,
    99
  ],
  [
    "589AAF",
    "Hippie Blue",
    88,
    154,
    175,
    137,
    89,
    131
  ],
  [
    "591D35",
    "Wine Berry",
    89,
    29,
    53,
    -17,
    129,
    58
  ],
  [
    "592804",
    "Brown Bramble",
    89,
    40,
    4,
    18,
    233,
    46
  ],
  [
    "593737",
    "Congo Brown",
    89,
    55,
    55,
    0,
    60,
    72
  ],
  [
    "594433",
    "Millbrook",
    89,
    68,
    51,
    19,
    69,
    70
  ],
  [
    "5A6E9C",
    "Waikawa Gray",
    90,
    110,
    156,
    157,
    68,
    123
  ],
  [
    "5A87A0",
    "Horizon",
    90,
    135,
    160,
    142,
    71,
    125
  ],
  [
    "5B3013",
    "Jambalaya",
    91,
    48,
    19,
    17,
    166,
    55
  ],
  [
    "5C0120",
    "Bordeaux",
    92,
    1,
    32,
    -14,
    249,
    46
  ],
  [
    "5C0536",
    "Mulberry Wood",
    92,
    5,
    54,
    -23,
    228,
    48
  ],
  [
    "5C2E01",
    "Carnaby Tan",
    92,
    46,
    1,
    21,
    249,
    46
  ],
  [
    "5C5D75",
    "Comet",
    92,
    93,
    117,
    168,
    30,
    104
  ],
  [
    "5D1E0F",
    "Redwood",
    93,
    30,
    15,
    8,
    184,
    54
  ],
  [
    "5D4C51",
    "Don Juan",
    93,
    76,
    81,
    -12,
    25,
    84
  ],
  [
    "5D5C58",
    "Chicago",
    93,
    92,
    88,
    34,
    7,
    90
  ],
  [
    "5D5E37",
    "Verdigris",
    93,
    94,
    55,
    43,
    66,
    74
  ],
  [
    "5D7747",
    "Dingley",
    93,
    119,
    71,
    65,
    64,
    95
  ],
  [
    "5DA19F",
    "Breaker Bay",
    93,
    161,
    159,
    126,
    68,
    127
  ],
  [
    "5E483E",
    "Kabul",
    94,
    72,
    62,
    13,
    52,
    78
  ],
  [
    "5E5D3B",
    "Hemlock",
    94,
    93,
    59,
    41,
    58,
    76
  ],
  [
    "5F3D26",
    "Irish Coffee",
    95,
    61,
    38,
    17,
    109,
    66
  ],
  [
    "5F5F6E",
    "Mid Gray",
    95,
    95,
    110,
    170,
    18,
    102
  ],
  [
    "5F6672",
    "Shuttle Gray",
    95,
    102,
    114,
    154,
    23,
    104
  ],
  [
    "5FA777",
    "Aqua Forest",
    95,
    167,
    119,
    99,
    74,
    131
  ],
  [
    "5FB3AC",
    "Tradewind",
    95,
    179,
    172,
    123,
    90,
    137
  ],
  [
    "604913",
    "Horses Neck",
    96,
    73,
    19,
    29,
    170,
    57
  ],
  [
    "605B73",
    "Smoky",
    96,
    91,
    115,
    178,
    29,
    103
  ],
  [
    "606E68",
    "Corduroy",
    96,
    110,
    104,
    109,
    17,
    103
  ],
  [
    "6093D1",
    "Danube",
    96,
    147,
    209,
    150,
    140,
    152
  ],
  [
    "612718",
    "Espresso",
    97,
    39,
    24,
    8,
    153,
    60
  ],
  [
    "614051",
    "Eggplant",
    97,
    64,
    81,
    -21,
    52,
    80
  ],
  [
    "615D30",
    "Costa Del Sol",
    97,
    93,
    48,
    39,
    86,
    72
  ],
  [
    "61845F",
    "Glade Green",
    97,
    132,
    95,
    82,
    41,
    113
  ],
  [
    "622F30",
    "Buccaneer",
    98,
    47,
    48,
    0,
    89,
    72
  ],
  [
    "623F2D",
    "Quincy",
    98,
    63,
    45,
    14,
    94,
    71
  ],
  [
    "624E9A",
    "Butterfly Bush",
    98,
    78,
    154,
    181,
    83,
    116
  ],
  [
    "625119",
    "West Coast",
    98,
    81,
    25,
    32,
    151,
    61
  ],
  [
    "626649",
    "Finch",
    98,
    102,
    73,
    48,
    42,
    87
  ],
  [
    "639A8F",
    "Patina",
    99,
    154,
    143,
    119,
    55,
    126
  ],
  [
    "63B76C",
    "Fern",
    99,
    183,
    108,
    89,
    93,
    141
  ],
  [
    "6456B7",
    "Blue Violet",
    100,
    86,
    183,
    176,
    102,
    134
  ],
  [
    "646077",
    "Dolphin",
    100,
    96,
    119,
    177,
    27,
    107
  ],
  [
    "646463",
    "Storm Dust",
    100,
    100,
    99,
    42,
    1,
    99
  ],
  [
    "646A54",
    "Siam",
    100,
    106,
    84,
    54,
    29,
    95
  ],
  [
    "646E75",
    "Nevada",
    100,
    110,
    117,
    144,
    19,
    108
  ],
  [
    "6495ED",
    "Cornflower Blue",
    100,
    149,
    237,
    154,
    201,
    168
  ],
  [
    "64CCDB",
    "Viking",
    100,
    204,
    219,
    132,
    158,
    159
  ],
  [
    "65000B",
    "Rosewood",
    101,
    0,
    11,
    -4,
    255,
    50
  ],
  [
    "651A14",
    "Cherrywood",
    101,
    26,
    20,
    3,
    170,
    60
  ],
  [
    "652DC1",
    "Purple Heart",
    101,
    45,
    193,
    186,
    158,
    119
  ],
  [
    "657220",
    "Fern Frond",
    101,
    114,
    32,
    49,
    143,
    73
  ],
  [
    "65745D",
    "Willow Grove",
    101,
    116,
    93,
    70,
    28,
    104
  ],
  [
    "65869F",
    "Hoki",
    101,
    134,
    159,
    145,
    59,
    130
  ],
  [
    "660045",
    "Pompadour",
    102,
    0,
    69,
    -28,
    255,
    51
  ],
  [
    "660099",
    "Purple",
    102,
    0,
    153,
    198,
    255,
    76
  ],
  [
    "66023C",
    "Tyrian Purple",
    102,
    2,
    60,
    -24,
    245,
    52
  ],
  [
    "661010",
    "Dark Tan",
    102,
    16,
    16,
    0,
    185,
    59
  ],
  [
    "66B58F",
    "Silver Tree",
    102,
    181,
    143,
    107,
    88,
    141
  ],
  [
    "66FF00",
    "Bright Green",
    102,
    255,
    0,
    68,
    255,
    127
  ],
  [
    "66FF66",
    "Screamin' Green",
    102,
    255,
    102,
    85,
    254,
    178
  ],
  [
    "67032D",
    "Black Rose",
    103,
    3,
    45,
    -17,
    240,
    53
  ],
  [
    "675FA6",
    "Scampi",
    103,
    95,
    166,
    174,
    72,
    130
  ],
  [
    "676662",
    "Ironside Gray",
    103,
    102,
    98,
    34,
    6,
    100
  ],
  [
    "678975",
    "Viridian Green",
    103,
    137,
    117,
    102,
    36,
    120
  ],
  [
    "67A712",
    "Christi",
    103,
    167,
    18,
    60,
    205,
    92
  ],
  [
    "683600",
    "Nutmeg Wood Finish",
    104,
    54,
    0,
    22,
    255,
    52
  ],
  [
    "685558",
    "Zambezi",
    104,
    85,
    88,
    -6,
    25,
    94
  ],
  [
    "685E6E",
    "Salt Box",
    104,
    94,
    110,
    196,
    20,
    102
  ],
  [
    "692545",
    "Tawny Port",
    105,
    37,
    69,
    -20,
    122,
    71
  ],
  [
    "692D54",
    "Finn",
    105,
    45,
    84,
    -27,
    101,
    75
  ],
  [
    "695F62",
    "Scorpion",
    105,
    95,
    98,
    -12,
    12,
    100
  ],
  [
    "697E9A",
    "Lynch",
    105,
    126,
    154,
    151,
    49,
    129
  ],
  [
    "6A442E",
    "Spice",
    106,
    68,
    46,
    15,
    100,
    76
  ],
  [
    "6A5D1B",
    "Himalaya",
    106,
    93,
    27,
    35,
    151,
    66
  ],
  [
    "6A6051",
    "Soya Bean",
    106,
    96,
    81,
    25,
    34,
    93
  ],
  [
    "6B2A14",
    "Hairy Heath",
    107,
    42,
    20,
    10,
    174,
    63
  ],
  [
    "6B3FA0",
    "Royal Purple",
    107,
    63,
    160,
    189,
    110,
    111
  ],
  [
    "6B4E31",
    "Shingle Fawn",
    107,
    78,
    49,
    21,
    94,
    78
  ],
  [
    "6B5755",
    "Dorado",
    107,
    87,
    85,
    3,
    29,
    96
  ],
  [
    "6B8BA2",
    "Bermuda Gray",
    107,
    139,
    162,
    145,
    58,
    134
  ],
  [
    "6B8E23",
    "Olive Drab",
    107,
    142,
    35,
    56,
    154,
    88
  ],
  [
    "6C3082",
    "Eminence",
    108,
    48,
    130,
    201,
    117,
    89
  ],
  [
    "6CDAE7",
    "Turquoise Blue",
    108,
    218,
    231,
    131,
    183,
    169
  ],
  [
    "6D0101",
    "Lonestar",
    109,
    1,
    1,
    0,
    250,
    54
  ],
  [
    "6D5E54",
    "Pine Cone",
    109,
    94,
    84,
    17,
    33,
    96
  ],
  [
    "6D6C6C",
    "Dove Gray",
    109,
    108,
    108,
    0,
    1,
    108
  ],
  [
    "6D9292",
    "Juniper",
    109,
    146,
    146,
    127,
    36,
    127
  ],
  [
    "6D92A1",
    "Gothic",
    109,
    146,
    161,
    139,
    55,
    135
  ],
  [
    "6E0902",
    "Red Oxide",
    110,
    9,
    2,
    2,
    245,
    56
  ],
  [
    "6E1D14",
    "Moccaccino",
    110,
    29,
    20,
    4,
    176,
    65
  ],
  [
    "6E4826",
    "Pickled Bean",
    110,
    72,
    38,
    20,
    124,
    74
  ],
  [
    "6E4B26",
    "Dallas",
    110,
    75,
    38,
    21,
    124,
    74
  ],
  [
    "6E6D57",
    "Kokoda",
    110,
    109,
    87,
    40,
    29,
    98
  ],
  [
    "6E7783",
    "Pale Sky",
    110,
    119,
    131,
    151,
    22,
    120
  ],
  [
    "6F440C",
    "Cafe Royale",
    111,
    68,
    12,
    24,
    205,
    61
  ],
  [
    "6F6A61",
    "Flint",
    111,
    106,
    97,
    27,
    17,
    104
  ],
  [
    "6F8E63",
    "Highland",
    111,
    142,
    99,
    73,
    45,
    120
  ],
  [
    "6F9D02",
    "Limeade",
    111,
    157,
    2,
    55,
    248,
    79
  ],
  [
    "6FD0C5",
    "Downy",
    111,
    208,
    197,
    122,
    129,
    159
  ],
  [
    "701C1C",
    "Persian Plum",
    112,
    28,
    28,
    0,
    153,
    70
  ],
  [
    "704214",
    "Sepia",
    112,
    66,
    20,
    21,
    177,
    65
  ],
  [
    "704A07",
    "Antique Bronze",
    112,
    74,
    7,
    27,
    225,
    59
  ],
  [
    "704F50",
    "Ferra",
    112,
    79,
    80,
    -1,
    44,
    95
  ],
  [
    "706555",
    "Coffee",
    112,
    101,
    85,
    25,
    34,
    98
  ],
  [
    "708090",
    "Slate Gray",
    112,
    128,
    144,
    148,
    32,
    128
  ],
  [
    "711A00",
    "Cedar Wood Finish",
    113,
    26,
    0,
    9,
    255,
    56
  ],
  [
    "71291D",
    "Metallic Copper",
    113,
    41,
    29,
    6,
    150,
    71
  ],
  [
    "714693",
    "Affair",
    113,
    70,
    147,
    193,
    90,
    108
  ],
  [
    "714AB2",
    "Studio",
    113,
    74,
    178,
    185,
    105,
    126
  ],
  [
    "715D47",
    "Tobacco Brown",
    113,
    93,
    71,
    22,
    58,
    92
  ],
  [
    "716338",
    "Yellow Metal",
    113,
    99,
    56,
    32,
    86,
    84
  ],
  [
    "716B56",
    "Peat",
    113,
    107,
    86,
    33,
    34,
    99
  ],
  [
    "716E10",
    "Olivetone",
    113,
    110,
    16,
    41,
    191,
    64
  ],
  [
    "717486",
    "Storm Gray",
    113,
    116,
    134,
    163,
    21,
    123
  ],
  [
    "718080",
    "Sirocco",
    113,
    128,
    128,
    127,
    15,
    120
  ],
  [
    "71D9E2",
    "Aquamarine Blue",
    113,
    217,
    226,
    130,
    168,
    169
  ],
  [
    "72010F",
    "Venetian Red",
    114,
    1,
    15,
    -5,
    250,
    57
  ],
  [
    "724A2F",
    "Old Copper",
    114,
    74,
    47,
    17,
    106,
    80
  ],
  [
    "726D4E",
    "Go Ben",
    114,
    109,
    78,
    36,
    47,
    96
  ],
  [
    "727B89",
    "Raven",
    114,
    123,
    137,
    153,
    23,
    125
  ],
  [
    "731E8F",
    "Seance",
    115,
    30,
    143,
    201,
    166,
    86
  ],
  [
    "734A12",
    "Raw Umber",
    115,
    74,
    18,
    24,
    185,
    66
  ],
  [
    "736C9F",
    "Kimberly",
    115,
    108,
    159,
    175,
    53,
    133
  ],
  [
    "736D58",
    "Crocodile",
    115,
    109,
    88,
    33,
    33,
    101
  ],
  [
    "737829",
    "Crete",
    115,
    120,
    41,
    45,
    125,
    80
  ],
  [
    "738678",
    "Xanadu",
    115,
    134,
    120,
    96,
    19,
    124
  ],
  [
    "74640D",
    "Spicy Mustard",
    116,
    100,
    13,
    35,
    203,
    64
  ],
  [
    "747D63",
    "Limed Ash",
    116,
    125,
    99,
    57,
    29,
    112
  ],
  [
    "747D83",
    "Rolling Stone",
    116,
    125,
    131,
    144,
    15,
    123
  ],
  [
    "748881",
    "Blue Smoke",
    116,
    136,
    129,
    112,
    20,
    126
  ],
  [
    "749378",
    "Laurel",
    116,
    147,
    120,
    90,
    32,
    131
  ],
  [
    "74C365",
    "Mantis",
    116,
    195,
    101,
    78,
    112,
    147
  ],
  [
    "755A57",
    "Russett",
    117,
    90,
    87,
    4,
    37,
    102
  ],
  [
    "7563A8",
    "Deluge",
    117,
    99,
    168,
    181,
    72,
    133
  ],
  [
    "76395D",
    "Cosmic",
    118,
    57,
    93,
    -25,
    88,
    87
  ],
  [
    "7666C6",
    "Blue Marguerite",
    118,
    102,
    198,
    177,
    116,
    150
  ],
  [
    "76BD17",
    "Lima",
    118,
    189,
    23,
    60,
    199,
    106
  ],
  [
    "76D7EA",
    "Sky Blue",
    118,
    215,
    234,
    134,
    187,
    176
  ],
  [
    "770F05",
    "Dark Burgundy",
    119,
    15,
    5,
    3,
    234,
    62
  ],
  [
    "771F1F",
    "Crown of Thorns",
    119,
    31,
    31,
    0,
    149,
    75
  ],
  [
    "773F1A",
    "Walnut",
    119,
    63,
    26,
    16,
    163,
    72
  ],
  [
    "776F61",
    "Pablo",
    119,
    111,
    97,
    27,
    25,
    108
  ],
  [
    "778120",
    "Pacifika",
    119,
    129,
    32,
    46,
    153,
    80
  ],
  [
    "779E86",
    "Oxley",
    119,
    158,
    134,
    101,
    42,
    138
  ],
  [
    "77DD77",
    "Pastel Green",
    119,
    221,
    119,
    85,
    153,
    170
  ],
  [
    "780109",
    "Japanese Maple",
    120,
    1,
    9,
    -2,
    250,
    60
  ],
  [
    "782D19",
    "Mocha",
    120,
    45,
    25,
    8,
    167,
    72
  ],
  [
    "782F16",
    "Peanut",
    120,
    47,
    22,
    10,
    175,
    71
  ],
  [
    "78866B",
    "Camouflage Green",
    120,
    134,
    107,
    64,
    28,
    120
  ],
  [
    "788A25",
    "Wasabi",
    120,
    138,
    37,
    50,
    147,
    87
  ],
  [
    "788BBA",
    "Ship Cove",
    120,
    139,
    186,
    157,
    82,
    153
  ],
  [
    "78A39C",
    "Sea Nymph",
    120,
    163,
    156,
    120,
    48,
    141
  ],
  [
    "795D4C",
    "Roman Coffee",
    121,
    93,
    76,
    16,
    58,
    98
  ],
  [
    "796878",
    "Old Lavender",
    121,
    104,
    120,
    -40,
    19,
    112
  ],
  [
    "796989",
    "Rum",
    121,
    105,
    137,
    191,
    33,
    121
  ],
  [
    "796A78",
    "Fedora",
    121,
    106,
    120,
    -39,
    16,
    113
  ],
  [
    "796D62",
    "Sandstone",
    121,
    109,
    98,
    20,
    26,
    109
  ],
  [
    "79DEEC",
    "Spray",
    121,
    222,
    236,
    132,
    191,
    178
  ],
  [
    "7A013A",
    "Siren",
    122,
    1,
    58,
    -20,
    250,
    61
  ],
  [
    "7A58C1",
    "Fuchsia Blue",
    122,
    88,
    193,
    183,
    116,
    140
  ],
  [
    "7A7A7A",
    "Boulder",
    122,
    122,
    122,
    0,
    0,
    122
  ],
  [
    "7A89B8",
    "Wild Blue Yonder",
    122,
    137,
    184,
    159,
    77,
    153
  ],
  [
    "7AC488",
    "De York",
    122,
    196,
    136,
    93,
    98,
    159
  ],
  [
    "7B3801",
    "Red Beech",
    123,
    56,
    1,
    19,
    250,
    62
  ],
  [
    "7B3F00",
    "Cinnamon",
    123,
    63,
    0,
    21,
    255,
    61
  ],
  [
    "7B6608",
    "Yukon Gold",
    123,
    102,
    8,
    34,
    223,
    65
  ],
  [
    "7B7874",
    "Tapa",
    123,
    120,
    116,
    24,
    7,
    119
  ],
  [
    "7B7C94",
    "Waterloo ",
    123,
    124,
    148,
    168,
    26,
    135
  ],
  [
    "7B8265",
    "Flax Smoke",
    123,
    130,
    101,
    52,
    32,
    115
  ],
  [
    "7B9F80",
    "Amulet",
    123,
    159,
    128,
    90,
    40,
    141
  ],
  [
    "7BA05B",
    "Asparagus",
    123,
    160,
    91,
    65,
    70,
    125
  ],
  [
    "7C1C05",
    "Kenyan Copper",
    124,
    28,
    5,
    8,
    235,
    64
  ],
  [
    "7C7631",
    "Pesto",
    124,
    118,
    49,
    39,
    110,
    86
  ],
  [
    "7C778A",
    "Topaz",
    124,
    119,
    138,
    181,
    19,
    128
  ],
  [
    "7C7B7A",
    "Concord",
    124,
    123,
    122,
    21,
    2,
    123
  ],
  [
    "7C7B82",
    "Jumbo",
    124,
    123,
    130,
    176,
    7,
    126
  ],
  [
    "7C881A",
    "Trendy Green",
    124,
    136,
    26,
    47,
    173,
    81
  ],
  [
    "7CA1A6",
    "Gumbo",
    124,
    161,
    166,
    132,
    48,
    145
  ],
  [
    "7CB0A1",
    "Acapulco",
    124,
    176,
    161,
    115,
    63,
    150
  ],
  [
    "7CB7BB",
    "Neptune",
    124,
    183,
    187,
    130,
    80,
    155
  ],
  [
    "7D2C14",
    "Pueblo",
    125,
    44,
    20,
    9,
    184,
    72
  ],
  [
    "7DA98D",
    "Bay Leaf",
    125,
    169,
    141,
    100,
    51,
    147
  ],
  [
    "7DC8F7",
    "Malibu",
    125,
    200,
    247,
    143,
    225,
    186
  ],
  [
    "7DD8C6",
    "Bermuda",
    125,
    216,
    198,
    119,
    137,
    170
  ],
  [
    "7E3A15",
    "Copper Canyon",
    126,
    58,
    21,
    14,
    182,
    73
  ],
  [
    "7F1734",
    "Claret",
    127,
    23,
    52,
    -11,
    176,
    75
  ],
  [
    "7F3A02",
    "Peru Tan",
    127,
    58,
    2,
    19,
    247,
    64
  ],
  [
    "7F626D",
    "Falcon",
    127,
    98,
    109,
    -16,
    32,
    112
  ],
  [
    "7F7589",
    "Mobster",
    127,
    117,
    137,
    191,
    20,
    127
  ],
  [
    "7F76D3",
    "Moody Blue",
    127,
    118,
    211,
    174,
    131,
    164
  ],
  [
    "7FFF00",
    "Chartreuse",
    127,
    255,
    0,
    63,
    255,
    127
  ],
  [
    "7FFFD4",
    "Aquamarine",
    127,
    255,
    212,
    113,
    255,
    191
  ],
  [
    "800000",
    "Maroon",
    128,
    0,
    0,
    0,
    255,
    64
  ],
  [
    "800B47",
    "Rose Bud Cherry",
    128,
    11,
    71,
    -21,
    214,
    69
  ],
  [
    "801818",
    "Falu Red",
    128,
    24,
    24,
    0,
    174,
    76
  ],
  [
    "80341F",
    "Red Robin",
    128,
    52,
    31,
    9,
    155,
    79
  ],
  [
    "803790",
    "Vivid Violet",
    128,
    55,
    144,
    204,
    114,
    99
  ],
  [
    "80461B",
    "Russet",
    128,
    70,
    27,
    18,
    166,
    77
  ],
  [
    "807E79",
    "Friar Gray",
    128,
    126,
    121,
    30,
    7,
    124
  ],
  [
    "808000",
    "Olive",
    128,
    128,
    0,
    42,
    255,
    64
  ],
  [
    "808080",
    "Gray",
    128,
    128,
    128,
    0,
    0,
    128
  ],
  [
    "80B3AE",
    "Gulf Stream",
    128,
    179,
    174,
    123,
    64,
    153
  ],
  [
    "80B3C4",
    "Glacier",
    128,
    179,
    196,
    138,
    93,
    162
  ],
  [
    "80CCEA",
    "Seagull",
    128,
    204,
    234,
    139,
    182,
    180
  ],
  [
    "81422C",
    "Nutmeg",
    129,
    66,
    44,
    11,
    125,
    86
  ],
  [
    "816E71",
    "Spicy Pink",
    129,
    110,
    113,
    -6,
    20,
    119
  ],
  [
    "817377",
    "Empress",
    129,
    115,
    119,
    -12,
    14,
    121
  ],
  [
    "819885",
    "Spanish Green",
    129,
    152,
    133,
    92,
    25,
    140
  ],
  [
    "826F65",
    "Sand Dune",
    130,
    111,
    101,
    14,
    32,
    115
  ],
  [
    "828685",
    "Gunsmoke",
    130,
    134,
    133,
    116,
    4,
    131
  ],
  [
    "828F72",
    "Battleship Gray",
    130,
    143,
    114,
    61,
    29,
    128
  ],
  [
    "831923",
    "Merlot",
    131,
    25,
    35,
    -4,
    173,
    77
  ],
  [
    "837050",
    "Shadow",
    131,
    112,
    80,
    26,
    61,
    105
  ],
  [
    "83AA5D",
    "Chelsea Cucumber",
    131,
    170,
    93,
    64,
    79,
    131
  ],
  [
    "83D0C6",
    "Monte Carlo",
    131,
    208,
    198,
    121,
    114,
    169
  ],
  [
    "843179",
    "Plum",
    132,
    49,
    121,
    -36,
    116,
    90
  ],
  [
    "84A0A0",
    "Granny Smith",
    132,
    160,
    160,
    127,
    32,
    146
  ],
  [
    "8581D9",
    "Chetwode Blue",
    133,
    129,
    217,
    171,
    136,
    173
  ],
  [
    "858470",
    "Bandicoot",
    133,
    132,
    112,
    40,
    21,
    122
  ],
  [
    "859FAF",
    "Bali Hai",
    133,
    159,
    175,
    143,
    53,
    154
  ],
  [
    "85C4CC",
    "Half Baked",
    133,
    196,
    204,
    132,
    104,
    168
  ],
  [
    "860111",
    "Red Devil",
    134,
    1,
    17,
    -5,
    251,
    67
  ],
  [
    "863C3C",
    "Lotus",
    134,
    60,
    60,
    0,
    97,
    97
  ],
  [
    "86483C",
    "Ironstone",
    134,
    72,
    60,
    6,
    97,
    97
  ],
  [
    "864D1E",
    "Bull Shot",
    134,
    77,
    30,
    19,
    161,
    82
  ],
  [
    "86560A",
    "Rusty Nail",
    134,
    86,
    10,
    26,
    219,
    72
  ],
  [
    "868974",
    "Bitter",
    134,
    137,
    116,
    48,
    21,
    126
  ],
  [
    "86949F",
    "Regent Gray",
    134,
    148,
    159,
    146,
    29,
    146
  ],
  [
    "871550",
    "Disco",
    135,
    21,
    80,
    -21,
    186,
    78
  ],
  [
    "87756E",
    "Americano",
    135,
    117,
    110,
    11,
    26,
    122
  ],
  [
    "877C7B",
    "Hurricane",
    135,
    124,
    123,
    3,
    12,
    129
  ],
  [
    "878D91",
    "Oslo Gray",
    135,
    141,
    145,
    144,
    11,
    140
  ],
  [
    "87AB39",
    "Sushi",
    135,
    171,
    57,
    55,
    127,
    113
  ],
  [
    "885342",
    "Spicy Mix",
    136,
    83,
    66,
    10,
    88,
    101
  ],
  [
    "886221",
    "Kumera",
    136,
    98,
    33,
    26,
    155,
    84
  ],
  [
    "888387",
    "Suva Gray",
    136,
    131,
    135,
    -34,
    5,
    133
  ],
  [
    "888D65",
    "Avocado",
    136,
    141,
    101,
    47,
    42,
    121
  ],
  [
    "893456",
    "Camelot",
    137,
    52,
    86,
    -17,
    114,
    94
  ],
  [
    "893843",
    "Solid Pink",
    137,
    56,
    67,
    -5,
    107,
    96
  ],
  [
    "894367",
    "Cannon Pink",
    137,
    67,
    103,
    -21,
    87,
    102
  ],
  [
    "897D6D",
    "Makara",
    137,
    125,
    109,
    24,
    29,
    122
  ],
  [
    "8A3324",
    "Burnt Umber",
    138,
    51,
    36,
    6,
    149,
    87
  ],
  [
    "8A73D6",
    "True V",
    138,
    115,
    214,
    179,
    139,
    164
  ],
  [
    "8A8360",
    "Clay Creek",
    138,
    131,
    96,
    35,
    45,
    117
  ],
  [
    "8A8389",
    "Monsoon",
    138,
    131,
    137,
    -36,
    7,
    134
  ],
  [
    "8A8F8A",
    "Stack",
    138,
    143,
    138,
    85,
    5,
    140
  ],
  [
    "8AB9F1",
    "Jordy Blue",
    138,
    185,
    241,
    150,
    200,
    189
  ],
  [
    "8B00FF",
    "Electric Violet",
    139,
    0,
    255,
    193,
    255,
    127
  ],
  [
    "8B0723",
    "Monarch",
    139,
    7,
    35,
    -9,
    230,
    73
  ],
  [
    "8B6B0B",
    "Corn Harvest",
    139,
    107,
    11,
    31,
    217,
    74
  ],
  [
    "8B8470",
    "Olive Haze",
    139,
    132,
    112,
    31,
    27,
    125
  ],
  [
    "8B847E",
    "Schooner",
    139,
    132,
    126,
    19,
    13,
    132
  ],
  [
    "8B8680",
    "Natural Gray",
    139,
    134,
    128,
    23,
    11,
    133
  ],
  [
    "8B9C90",
    "Mantle",
    139,
    156,
    144,
    97,
    20,
    147
  ],
  [
    "8B9FEE",
    "Portage",
    139,
    159,
    238,
    161,
    189,
    188
  ],
  [
    "8BA690",
    "Envy",
    139,
    166,
    144,
    92,
    33,
    152
  ],
  [
    "8BA9A5",
    "Cascade",
    139,
    169,
    165,
    121,
    37,
    154
  ],
  [
    "8BE6D8",
    "Riptide",
    139,
    230,
    216,
    120,
    164,
    184
  ],
  [
    "8C055E",
    "Cardinal Pink",
    140,
    5,
    94,
    -28,
    237,
    72
  ],
  [
    "8C472F",
    "Mule Fawn",
    140,
    71,
    47,
    10,
    126,
    93
  ],
  [
    "8C5738",
    "Potters Clay",
    140,
    87,
    56,
    15,
    109,
    98
  ],
  [
    "8C6495",
    "Trendy Pink",
    140,
    100,
    149,
    204,
    50,
    124
  ],
  [
    "8D0226",
    "Paprika",
    141,
    2,
    38,
    -11,
    247,
    71
  ],
  [
    "8D3D38",
    "Sanguine Brown",
    141,
    61,
    56,
    2,
    110,
    98
  ],
  [
    "8D3F3F",
    "Tosca",
    141,
    63,
    63,
    0,
    97,
    102
  ],
  [
    "8D7662",
    "Cement",
    141,
    118,
    98,
    19,
    45,
    119
  ],
  [
    "8D8974",
    "Granite Green",
    141,
    137,
    116,
    35,
    25,
    128
  ],
  [
    "8D90A1",
    "Manatee",
    141,
    144,
    161,
    163,
    24,
    151
  ],
  [
    "8DA8CC",
    "Polo Blue",
    141,
    168,
    204,
    151,
    97,
    172
  ],
  [
    "8E0000",
    "Red Berry",
    142,
    0,
    0,
    0,
    255,
    71
  ],
  [
    "8E4D1E",
    "Rope",
    142,
    77,
    30,
    17,
    166,
    86
  ],
  [
    "8E6F70",
    "Opium",
    142,
    111,
    112,
    -1,
    31,
    126
  ],
  [
    "8E775E",
    "Domino",
    142,
    119,
    94,
    22,
    51,
    118
  ],
  [
    "8E8190",
    "Mamba",
    142,
    129,
    144,
    206,
    16,
    136
  ],
  [
    "8EABC1",
    "Nepal",
    142,
    171,
    193,
    145,
    74,
    167
  ],
  [
    "8F021C",
    "Pohutukawa",
    143,
    2,
    28,
    -7,
    247,
    72
  ],
  [
    "8F3E33",
    "El Salva",
    143,
    62,
    51,
    5,
    120,
    97
  ],
  [
    "8F4B0E",
    "Korma",
    143,
    75,
    14,
    20,
    209,
    78
  ],
  [
    "8F8176",
    "Squirrel",
    143,
    129,
    118,
    18,
    25,
    130
  ],
  [
    "8FD6B4",
    "Vista Blue",
    143,
    214,
    180,
    107,
    118,
    178
  ],
  [
    "900020",
    "Burgundy",
    144,
    0,
    32,
    -9,
    255,
    72
  ],
  [
    "901E1E",
    "Old Brick",
    144,
    30,
    30,
    0,
    167,
    87
  ],
  [
    "907874",
    "Hemp",
    144,
    120,
    116,
    6,
    28,
    130
  ],
  [
    "907B71",
    "Almond Frost",
    144,
    123,
    113,
    13,
    31,
    128
  ],
  [
    "908D39",
    "Sycamore",
    144,
    141,
    57,
    41,
    110,
    100
  ],
  [
    "92000A",
    "Sangria",
    146,
    0,
    10,
    -2,
    255,
    73
  ],
  [
    "924321",
    "Cumin",
    146,
    67,
    33,
    12,
    160,
    89
  ],
  [
    "926F5B",
    "Beaver",
    146,
    111,
    91,
    15,
    59,
    118
  ],
  [
    "928573",
    "Stonewall",
    146,
    133,
    115,
    24,
    31,
    130
  ],
  [
    "928590",
    "Venus",
    146,
    133,
    144,
    -35,
    14,
    139
  ],
  [
    "9370DB",
    "Medium Purple",
    147,
    112,
    219,
    183,
    152,
    165
  ],
  [
    "93CCEA",
    "Cornflower",
    147,
    204,
    234,
    142,
    171,
    190
  ],
  [
    "93DFB8",
    "Algae Green",
    147,
    223,
    184,
    105,
    138,
    185
  ],
  [
    "944747",
    "Copper Rust",
    148,
    71,
    71,
    0,
    89,
    109
  ],
  [
    "948771",
    "Arrowtown",
    148,
    135,
    113,
    26,
    35,
    130
  ],
  [
    "950015",
    "Scarlett",
    149,
    0,
    21,
    -5,
    255,
    74
  ],
  [
    "956387",
    "Strikemaster",
    149,
    99,
    135,
    -30,
    51,
    124
  ],
  [
    "959396",
    "Mountain Mist",
    149,
    147,
    150,
    198,
    3,
    148
  ],
  [
    "960018",
    "Carmine",
    150,
    0,
    24,
    -6,
    255,
    75
  ],
  [
    "964B00",
    "Brown",
    150,
    75,
    0,
    21,
    255,
    75
  ],
  [
    "967059",
    "Leather",
    150,
    112,
    89,
    16,
    65,
    119
  ],
  [
    "9678B6",
    "Purple Mountain's Majesty",
    150,
    120,
    182,
    190,
    76,
    151
  ],
  [
    "967BB6",
    "Lavender Purple",
    150,
    123,
    182,
    189,
    73,
    152
  ],
  [
    "96A8A1",
    "Pewter",
    150,
    168,
    161,
    110,
    23,
    159
  ],
  [
    "96BBAB",
    "Summer Green",
    150,
    187,
    171,
    109,
    54,
    168
  ],
  [
    "97605D",
    "Au Chico",
    151,
    96,
    93,
    2,
    60,
    121
  ],
  [
    "9771B5",
    "Wisteria",
    151,
    113,
    181,
    193,
    80,
    147
  ],
  [
    "97CD2D",
    "Atlantis",
    151,
    205,
    45,
    56,
    163,
    125
  ],
  [
    "983D61",
    "Vin Rouge",
    152,
    61,
    97,
    -16,
    108,
    106
  ],
  [
    "9874D3",
    "Lilac Bush",
    152,
    116,
    211,
    186,
    132,
    163
  ],
  [
    "98777B",
    "Bazaar",
    152,
    119,
    123,
    -5,
    35,
    135
  ],
  [
    "98811B",
    "Hacienda",
    152,
    129,
    27,
    34,
    178,
    89
  ],
  [
    "988D77",
    "Pale Oyster",
    152,
    141,
    119,
    28,
    35,
    135
  ],
  [
    "98FF98",
    "Mint Green",
    152,
    255,
    152,
    85,
    255,
    203
  ],
  [
    "990066",
    "Fresh Eggplant",
    153,
    0,
    102,
    -28,
    255,
    76
  ],
  [
    "991199",
    "Violet Eggplant",
    153,
    17,
    153,
    -42,
    204,
    85
  ],
  [
    "991613",
    "Tamarillo",
    153,
    22,
    19,
    0,
    198,
    85
  ],
  [
    "991B07",
    "Totem Pole",
    153,
    27,
    7,
    5,
    232,
    80
  ],
  [
    "996666",
    "Copper Rose",
    153,
    102,
    102,
    0,
    50,
    127
  ],
  [
    "9966CC",
    "Amethyst",
    153,
    102,
    204,
    191,
    127,
    153
  ],
  [
    "997A8D",
    "Mountbatten Pink",
    153,
    122,
    141,
    -26,
    33,
    137
  ],
  [
    "9999CC",
    "Blue Bell",
    153,
    153,
    204,
    170,
    85,
    178
  ],
  [
    "9A3820",
    "Prairie Sand",
    154,
    56,
    32,
    8,
    167,
    93
  ],
  [
    "9A6E61",
    "Toast",
    154,
    110,
    97,
    9,
    57,
    125
  ],
  [
    "9A9577",
    "Gurkha",
    154,
    149,
    119,
    36,
    37,
    136
  ],
  [
    "9AB973",
    "Olivine",
    154,
    185,
    115,
    61,
    85,
    150
  ],
  [
    "9AC2B8",
    "Shadow Green",
    154,
    194,
    184,
    116,
    62,
    174
  ],
  [
    "9B4703",
    "Oregon",
    155,
    71,
    3,
    19,
    245,
    78
  ],
  [
    "9B9E8F",
    "Lemon Grass",
    155,
    158,
    143,
    51,
    18,
    150
  ],
  [
    "9C3336",
    "Stiletto",
    156,
    51,
    54,
    -1,
    129,
    103
  ],
  [
    "9D5616",
    "Hawaiian Tan",
    157,
    86,
    22,
    20,
    192,
    89
  ],
  [
    "9DACB7",
    "Gull Gray",
    157,
    172,
    183,
    145,
    38,
    170
  ],
  [
    "9DC209",
    "Pistachio",
    157,
    194,
    9,
    50,
    232,
    101
  ],
  [
    "9DE093",
    "Granny Smith Apple",
    157,
    224,
    147,
    79,
    141,
    185
  ],
  [
    "9DE5FF",
    "Anakiwa",
    157,
    229,
    255,
    138,
    255,
    206
  ],
  [
    "9E5302",
    "Chelsea Gem",
    158,
    83,
    2,
    22,
    248,
    80
  ],
  [
    "9E5B40",
    "Sepia Skin",
    158,
    91,
    64,
    12,
    107,
    111
  ],
  [
    "9EA587",
    "Sage",
    158,
    165,
    135,
    52,
    36,
    150
  ],
  [
    "9EA91F",
    "Citron",
    158,
    169,
    31,
    45,
    175,
    100
  ],
  [
    "9EB1CD",
    "Rock Blue",
    158,
    177,
    205,
    152,
    81,
    181
  ],
  [
    "9EDEE0",
    "Morning Glory",
    158,
    222,
    224,
    128,
    131,
    191
  ],
  [
    "9F381D",
    "Cognac",
    159,
    56,
    29,
    8,
    176,
    94
  ],
  [
    "9F821C",
    "Reef Gold",
    159,
    130,
    28,
    33,
    178,
    93
  ],
  [
    "9F9F9C",
    "Star Dust",
    159,
    159,
    156,
    42,
    3,
    157
  ],
  [
    "9FA0B1",
    "Santas Gray",
    159,
    160,
    177,
    167,
    26,
    168
  ],
  [
    "9FD7D3",
    "Sinbad",
    159,
    215,
    211,
    124,
    105,
    187
  ],
  [
    "9FDD8C",
    "Feijoa",
    159,
    221,
    140,
    75,
    138,
    180
  ],
  [
    "A02712",
    "Tabasco",
    160,
    39,
    18,
    6,
    203,
    89
  ],
  [
    "A1750D",
    "Buttered Rum",
    161,
    117,
    13,
    29,
    216,
    87
  ],
  [
    "A1ADB5",
    "Hit Gray",
    161,
    173,
    181,
    144,
    30,
    171
  ],
  [
    "A1C50A",
    "Citrus",
    161,
    197,
    10,
    50,
    230,
    103
  ],
  [
    "A1DAD7",
    "Aqua Island",
    161,
    218,
    215,
    125,
    110,
    189
  ],
  [
    "A1E9DE",
    "Water Leaf",
    161,
    233,
    222,
    121,
    158,
    196
  ],
  [
    "A2006D",
    "Flirt",
    162,
    0,
    109,
    -28,
    255,
    81
  ],
  [
    "A23B6C",
    "Rouge",
    162,
    59,
    108,
    -20,
    118,
    110
  ],
  [
    "A26645",
    "Cape Palliser",
    162,
    102,
    69,
    15,
    102,
    115
  ],
  [
    "A2AAB3",
    "Gray Chateau",
    162,
    170,
    179,
    150,
    25,
    170
  ],
  [
    "A2AEAB",
    "Edward",
    162,
    174,
    171,
    116,
    17,
    168
  ],
  [
    "A3807B",
    "Pharlap",
    163,
    128,
    123,
    5,
    45,
    143
  ],
  [
    "A397B4",
    "Amethyst Smoke",
    163,
    151,
    180,
    187,
    41,
    165
  ],
  [
    "A3E3ED",
    "Blizzard Blue",
    163,
    227,
    237,
    133,
    171,
    200
  ],
  [
    "A4A49D",
    "Delta",
    164,
    164,
    157,
    42,
    9,
    160
  ],
  [
    "A4A6D3",
    "Wistful",
    164,
    166,
    211,
    168,
    88,
    187
  ],
  [
    "A4AF6E",
    "Green Smoke",
    164,
    175,
    110,
    49,
    73,
    142
  ],
  [
    "A50B5E",
    "Jazzberry Jam",
    165,
    11,
    94,
    -22,
    223,
    88
  ],
  [
    "A59B91",
    "Zorba",
    165,
    155,
    145,
    21,
    25,
    155
  ],
  [
    "A5CB0C",
    "Bahia",
    165,
    203,
    12,
    50,
    226,
    107
  ],
  [
    "A62F20",
    "Roof Terracotta",
    166,
    47,
    32,
    4,
    172,
    99
  ],
  [
    "A65529",
    "Paarl",
    166,
    85,
    41,
    14,
    153,
    103
  ],
  [
    "A68B5B",
    "Barley Corn",
    166,
    139,
    91,
    27,
    75,
    128
  ],
  [
    "A69279",
    "Donkey Brown",
    166,
    146,
    121,
    23,
    51,
    143
  ],
  [
    "A6A29A",
    "Dawn",
    166,
    162,
    154,
    28,
    16,
    160
  ],
  [
    "A72525",
    "Mexican Red",
    167,
    37,
    37,
    0,
    162,
    102
  ],
  [
    "A7882C",
    "Luxor Gold",
    167,
    136,
    44,
    31,
    148,
    105
  ],
  [
    "A85307",
    "Rich Gold",
    168,
    83,
    7,
    20,
    234,
    87
  ],
  [
    "A86515",
    "Reno Sand",
    168,
    101,
    21,
    23,
    198,
    94
  ],
  [
    "A86B6B",
    "Coral Tree",
    168,
    107,
    107,
    0,
    66,
    137
  ],
  [
    "A8989B",
    "Dusty Gray",
    168,
    152,
    155,
    -7,
    21,
    160
  ],
  [
    "A899E6",
    "Dull Lavender",
    168,
    153,
    230,
    178,
    154,
    191
  ],
  [
    "A8A589",
    "Tallow",
    168,
    165,
    137,
    38,
    38,
    152
  ],
  [
    "A8AE9C",
    "Bud",
    168,
    174,
    156,
    56,
    25,
    165
  ],
  [
    "A8AF8E",
    "Locust",
    168,
    175,
    142,
    51,
    43,
    158
  ],
  [
    "A8BD9F",
    "Norway",
    168,
    189,
    159,
    72,
    47,
    174
  ],
  [
    "A8E3BD",
    "Chinook",
    168,
    227,
    189,
    100,
    130,
    197
  ],
  [
    "A9A491",
    "Gray Olive",
    169,
    164,
    145,
    33,
    31,
    157
  ],
  [
    "A9ACB6",
    "Aluminium",
    169,
    172,
    182,
    160,
    20,
    175
  ],
  [
    "A9B2C3",
    "Cadet Blue",
    169,
    178,
    195,
    155,
    45,
    181
  ],
  [
    "A9B497",
    "Schist",
    169,
    180,
    151,
    58,
    41,
    165
  ],
  [
    "A9BDBF",
    "Tower Gray",
    169,
    189,
    191,
    131,
    37,
    179
  ],
  [
    "A9BEF2",
    "Perano",
    169,
    190,
    242,
    157,
    188,
    205
  ],
  [
    "A9C6C2",
    "Opal",
    169,
    198,
    194,
    121,
    51,
    183
  ],
  [
    "AA375A",
    "Night Shadz",
    170,
    55,
    90,
    -12,
    130,
    112
  ],
  [
    "AA4203",
    "Fire",
    170,
    66,
    3,
    16,
    246,
    86
  ],
  [
    "AA8B5B",
    "Muesli",
    170,
    139,
    91,
    25,
    80,
    130
  ],
  [
    "AA8D6F",
    "Sandal",
    170,
    141,
    111,
    21,
    65,
    140
  ],
  [
    "AAA5A9",
    "Shady Lady",
    170,
    165,
    169,
    -34,
    7,
    167
  ],
  [
    "AAA9CD",
    "Logan",
    170,
    169,
    205,
    171,
    67,
    187
  ],
  [
    "AAABB7",
    "Spun Pearl",
    170,
    171,
    183,
    166,
    21,
    176
  ],
  [
    "AAD6E6",
    "Regent St Blue",
    170,
    214,
    230,
    138,
    139,
    200
  ],
  [
    "AAF0D1",
    "Magic Mint",
    170,
    240,
    209,
    108,
    178,
    205
  ],
  [
    "AB0563",
    "Lipstick",
    171,
    5,
    99,
    -24,
    240,
    88
  ],
  [
    "AB3472",
    "Royal Heath",
    171,
    52,
    114,
    -22,
    136,
    111
  ],
  [
    "AB917A",
    "Sandrift",
    171,
    145,
    122,
    19,
    57,
    146
  ],
  [
    "ABA0D9",
    "Cold Purple",
    171,
    160,
    217,
    178,
    109,
    188
  ],
  [
    "ABA196",
    "Bronco",
    171,
    161,
    150,
    22,
    28,
    160
  ],
  [
    "AC8A56",
    "Limed Oak",
    172,
    138,
    86,
    25,
    87,
    129
  ],
  [
    "AC91CE",
    "East Side",
    172,
    145,
    206,
    188,
    97,
    175
  ],
  [
    "AC9E22",
    "Lemon Ginger",
    172,
    158,
    34,
    38,
    170,
    103
  ],
  [
    "ACA494",
    "Napa",
    172,
    164,
    148,
    28,
    32,
    160
  ],
  [
    "ACA586",
    "Hillary",
    172,
    165,
    134,
    34,
    47,
    153
  ],
  [
    "ACA59F",
    "Cloudy",
    172,
    165,
    159,
    19,
    18,
    165
  ],
  [
    "ACACAC",
    "Silver Chalice",
    172,
    172,
    172,
    0,
    0,
    172
  ],
  [
    "ACB78E",
    "Swamp Green",
    172,
    183,
    142,
    53,
    56,
    162
  ],
  [
    "ACCBB1",
    "Spring Rain",
    172,
    203,
    177,
    91,
    58,
    187
  ],
  [
    "ACDD4D",
    "Conifer",
    172,
    221,
    77,
    56,
    173,
    149
  ],
  [
    "ACE1AF",
    "Celadon",
    172,
    225,
    175,
    87,
    119,
    198
  ],
  [
    "AD781B",
    "Mandalay",
    173,
    120,
    27,
    27,
    186,
    100
  ],
  [
    "ADBED1",
    "Casper",
    173,
    190,
    209,
    149,
    71,
    191
  ],
  [
    "ADDFAD",
    "Moss Green",
    173,
    223,
    173,
    85,
    111,
    198
  ],
  [
    "ADE6C4",
    "Padua",
    173,
    230,
    196,
    102,
    135,
    201
  ],
  [
    "ADFF2F",
    "Green Yellow",
    173,
    255,
    47,
    59,
    255,
    151
  ],
  [
    "AE4560",
    "Hippie Pink",
    174,
    69,
    96,
    -10,
    110,
    121
  ],
  [
    "AE6020",
    "Desert",
    174,
    96,
    32,
    19,
    175,
    103
  ],
  [
    "AE809E",
    "Bouquet",
    174,
    128,
    158,
    -27,
    56,
    151
  ],
  [
    "AF4035",
    "Medium Carmine",
    175,
    64,
    53,
    3,
    136,
    114
  ],
  [
    "AF4D43",
    "Apple Blossom",
    175,
    77,
    67,
    3,
    113,
    121
  ],
  [
    "AF593E",
    "Brown Rust",
    175,
    89,
    62,
    10,
    121,
    118
  ],
  [
    "AF8751",
    "Driftwood",
    175,
    135,
    81,
    24,
    94,
    128
  ],
  [
    "AF8F2C",
    "Alpine",
    175,
    143,
    44,
    32,
    152,
    109
  ],
  [
    "AF9F1C",
    "Lucky",
    175,
    159,
    28,
    37,
    184,
    101
  ],
  [
    "AFA09E",
    "Martini",
    175,
    160,
    158,
    4,
    24,
    166
  ],
  [
    "AFB1B8",
    "Bombay",
    175,
    177,
    184,
    160,
    15,
    179
  ],
  [
    "AFBDD9",
    "Pigeon Post",
    175,
    189,
    217,
    155,
    90,
    195
  ],
  [
    "B04C6A",
    "Cadillac",
    176,
    76,
    106,
    -12,
    101,
    126
  ],
  [
    "B05D54",
    "Matrix",
    176,
    93,
    84,
    4,
    93,
    130
  ],
  [
    "B05E81",
    "Tapestry",
    176,
    94,
    129,
    -18,
    87,
    135
  ],
  [
    "B06608",
    "Mai Tai",
    176,
    102,
    8,
    23,
    232,
    92
  ],
  [
    "B09A95",
    "Del Rio",
    176,
    154,
    149,
    7,
    37,
    162
  ],
  [
    "B0E0E6",
    "Powder Blue",
    176,
    224,
    230,
    132,
    132,
    203
  ],
  [
    "B0E313",
    "Inch Worm",
    176,
    227,
    19,
    52,
    215,
    122
  ],
  [
    "B10000",
    "Bright Red",
    177,
    0,
    0,
    0,
    255,
    88
  ],
  [
    "B14A0B",
    "Vesuvius",
    177,
    74,
    11,
    16,
    225,
    93
  ],
  [
    "B1610B",
    "Pumpkin Skin",
    177,
    97,
    11,
    22,
    225,
    93
  ],
  [
    "B16D52",
    "Santa Fe",
    177,
    109,
    82,
    12,
    96,
    129
  ],
  [
    "B19461",
    "Teak",
    177,
    148,
    97,
    27,
    86,
    137
  ],
  [
    "B1E2C1",
    "Fringy Flower",
    177,
    226,
    193,
    98,
    116,
    201
  ],
  [
    "B1F4E7",
    "Ice Cold",
    177,
    244,
    231,
    119,
    191,
    210
  ],
  [
    "B20931",
    "Shiraz",
    178,
    9,
    49,
    -10,
    230,
    93
  ],
  [
    "B2A1EA",
    "Biloba Flower",
    178,
    161,
    234,
    179,
    161,
    197
  ],
  [
    "B32D29",
    "Tall Poppy",
    179,
    45,
    41,
    1,
    159,
    109
  ],
  [
    "B35213",
    "Fiery Orange",
    179,
    82,
    19,
    16,
    206,
    98
  ],
  [
    "B38007",
    "Hot Toddy",
    179,
    128,
    7,
    29,
    235,
    93
  ],
  [
    "B3AF95",
    "Taupe Gray",
    179,
    175,
    149,
    36,
    42,
    163
  ],
  [
    "B3C110",
    "La Rioja",
    179,
    193,
    16,
    45,
    215,
    104
  ],
  [
    "B43332",
    "Well Read",
    180,
    51,
    50,
    0,
    144,
    115
  ],
  [
    "B44668",
    "Blush",
    180,
    70,
    104,
    -13,
    112,
    125
  ],
  [
    "B4CFD3",
    "Jungle Mist",
    180,
    207,
    211,
    132,
    66,
    195
  ],
  [
    "B57281",
    "Turkish Rose",
    181,
    114,
    129,
    -9,
    79,
    147
  ],
  [
    "B57EDC",
    "Lavender",
    181,
    126,
    220,
    194,
    146,
    173
  ],
  [
    "B5A27F",
    "Mongoose",
    181,
    162,
    127,
    27,
    68,
    154
  ],
  [
    "B5B35C",
    "Olive Green",
    181,
    179,
    92,
    41,
    95,
    136
  ],
  [
    "B5D2CE",
    "Jet Stream",
    181,
    210,
    206,
    121,
    62,
    195
  ],
  [
    "B5ECDF",
    "Cruise",
    181,
    236,
    223,
    117,
    150,
    208
  ],
  [
    "B6316C",
    "Hibiscus",
    182,
    49,
    108,
    -18,
    146,
    115
  ],
  [
    "B69D98",
    "Thatch",
    182,
    157,
    152,
    7,
    43,
    167
  ],
  [
    "B6B095",
    "Heathered Gray",
    182,
    176,
    149,
    34,
    47,
    165
  ],
  [
    "B6BAA4",
    "Eagle",
    182,
    186,
    164,
    50,
    35,
    175
  ],
  [
    "B6D1EA",
    "Spindle",
    182,
    209,
    234,
    147,
    141,
    208
  ],
  [
    "B6D3BF",
    "Gum Leaf",
    182,
    211,
    191,
    98,
    63,
    196
  ],
  [
    "B7410E",
    "Rust",
    183,
    65,
    14,
    12,
    218,
    98
  ],
  [
    "B78E5C",
    "Muddy Waters",
    183,
    142,
    92,
    23,
    98,
    137
  ],
  [
    "B7A214",
    "Sahara",
    183,
    162,
    20,
    37,
    204,
    101
  ],
  [
    "B7A458",
    "Husk",
    183,
    164,
    88,
    34,
    101,
    135
  ],
  [
    "B7B1B1",
    "Nobel",
    183,
    177,
    177,
    0,
    10,
    179
  ],
  [
    "B7C3D0",
    "Heather",
    183,
    195,
    208,
    149,
    53,
    195
  ],
  [
    "B7F0BE",
    "Madang",
    183,
    240,
    190,
    90,
    167,
    211
  ],
  [
    "B81104",
    "Milano Red",
    184,
    17,
    4,
    3,
    244,
    94
  ],
  [
    "B87333",
    "Copper",
    184,
    115,
    51,
    20,
    144,
    117
  ],
  [
    "B8B56A",
    "Gimblet",
    184,
    181,
    106,
    40,
    90,
    145
  ],
  [
    "B8C1B1",
    "Green Spring",
    184,
    193,
    177,
    66,
    29,
    185
  ],
  [
    "B8C25D",
    "Celery",
    184,
    194,
    93,
    46,
    115,
    143
  ],
  [
    "B8E0F9",
    "Sail",
    184,
    224,
    249,
    143,
    215,
    216
  ],
  [
    "B94E48",
    "Chestnut",
    185,
    78,
    72,
    2,
    113,
    128
  ],
  [
    "B95140",
    "Crail",
    185,
    81,
    64,
    5,
    123,
    124
  ],
  [
    "B98D28",
    "Marigold",
    185,
    141,
    40,
    29,
    164,
    112
  ],
  [
    "B9C46A",
    "Wild Willow",
    185,
    196,
    106,
    47,
    110,
    151
  ],
  [
    "B9C8AC",
    "Rainee",
    185,
    200,
    172,
    65,
    51,
    186
  ],
  [
    "BA0101",
    "Guardsman Red",
    186,
    1,
    1,
    0,
    252,
    93
  ],
  [
    "BA450C",
    "Rock Spray",
    186,
    69,
    12,
    13,
    224,
    98
  ],
  [
    "BA6F1E",
    "Bourbon",
    186,
    111,
    30,
    22,
    184,
    108
  ],
  [
    "BA7F03",
    "Pirate Gold",
    186,
    127,
    3,
    28,
    246,
    94
  ],
  [
    "BAB1A2",
    "Nomad",
    186,
    177,
    162,
    26,
    37,
    174
  ],
  [
    "BAC7C9",
    "Submarine",
    186,
    199,
    201,
    133,
    31,
    193
  ],
  [
    "BAEEF9",
    "Charlotte",
    186,
    238,
    249,
    134,
    214,
    217
  ],
  [
    "BB3385",
    "Medium Red Violet",
    187,
    51,
    133,
    -25,
    145,
    119
  ],
  [
    "BB8983",
    "Brandy Rose",
    187,
    137,
    131,
    4,
    74,
    159
  ],
  [
    "BBD009",
    "Rio Grande",
    187,
    208,
    9,
    46,
    233,
    108
  ],
  [
    "BBD7C1",
    "Surf",
    187,
    215,
    193,
    94,
    66,
    201
  ],
  [
    "BCC9C2",
    "Powder Ash",
    188,
    201,
    194,
    104,
    27,
    194
  ],
  [
    "BD5E2E",
    "Tuscany",
    189,
    94,
    46,
    14,
    155,
    117
  ],
  [
    "BD978E",
    "Quicksand",
    189,
    151,
    142,
    8,
    66,
    165
  ],
  [
    "BDB1A8",
    "Silk",
    189,
    177,
    168,
    18,
    35,
    178
  ],
  [
    "BDB2A1",
    "Malta",
    189,
    178,
    161,
    25,
    44,
    175
  ],
  [
    "BDB3C7",
    "Chatelle",
    189,
    179,
    199,
    191,
    38,
    189
  ],
  [
    "BDBBD7",
    "Lavender Gray",
    189,
    187,
    215,
    173,
    66,
    201
  ],
  [
    "BDBDC6",
    "French Gray",
    189,
    189,
    198,
    170,
    18,
    193
  ],
  [
    "BDC8B3",
    "Clay Ash",
    189,
    200,
    179,
    64,
    40,
    189
  ],
  [
    "BDC9CE",
    "Loblolly",
    189,
    201,
    206,
    140,
    37,
    197
  ],
  [
    "BDEDFD",
    "French Pass",
    189,
    237,
    253,
    138,
    240,
    221
  ],
  [
    "BEA6C3",
    "London Hue",
    190,
    166,
    195,
    205,
    49,
    180
  ],
  [
    "BEB5B7",
    "Pink Swan",
    190,
    181,
    183,
    -9,
    16,
    185
  ],
  [
    "BEDE0D",
    "Fuego",
    190,
    222,
    13,
    49,
    226,
    117
  ],
  [
    "BF5500",
    "Rose of Sharon",
    191,
    85,
    0,
    18,
    255,
    95
  ],
  [
    "BFB8B0",
    "Tide",
    191,
    184,
    176,
    22,
    26,
    183
  ],
  [
    "BFBED8",
    "Blue Haze",
    191,
    190,
    216,
    171,
    63,
    203
  ],
  [
    "BFC1C2",
    "Silver Sand",
    191,
    193,
    194,
    141,
    6,
    192
  ],
  [
    "BFC921",
    "Key Lime Pie",
    191,
    201,
    33,
    45,
    183,
    117
  ],
  [
    "BFDBE2",
    "Ziggurat",
    191,
    219,
    226,
    136,
    95,
    208
  ],
  [
    "BFFF00",
    "Lime",
    191,
    255,
    0,
    53,
    255,
    127
  ],
  [
    "C02B18",
    "Thunderbird",
    192,
    43,
    24,
    4,
    198,
    108
  ],
  [
    "C04737",
    "Mojo",
    192,
    71,
    55,
    4,
    141,
    123
  ],
  [
    "C08081",
    "Old Rose",
    192,
    128,
    129,
    0,
    85,
    160
  ],
  [
    "C0C0C0",
    "Silver",
    192,
    192,
    192,
    0,
    0,
    192
  ],
  [
    "C0D3B9",
    "Pale Leaf",
    192,
    211,
    185,
    73,
    58,
    197
  ],
  [
    "C0D8B6",
    "Pixie Green",
    192,
    216,
    182,
    72,
    77,
    199
  ],
  [
    "C1440E",
    "Tia Maria",
    193,
    68,
    14,
    12,
    220,
    103
  ],
  [
    "C154C1",
    "Fuchsia Pink",
    193,
    84,
    193,
    -42,
    119,
    138
  ],
  [
    "C1A004",
    "Buddha Gold",
    193,
    160,
    4,
    35,
    244,
    98
  ],
  [
    "C1B7A4",
    "Bison Hide",
    193,
    183,
    164,
    27,
    48,
    178
  ],
  [
    "C1BAB0",
    "Tea",
    193,
    186,
    176,
    24,
    30,
    184
  ],
  [
    "C1BECD",
    "Gray Suit",
    193,
    190,
    205,
    178,
    33,
    197
  ],
  [
    "C1D7B0",
    "Sprout",
    193,
    215,
    176,
    66,
    83,
    195
  ],
  [
    "C1F07C",
    "Sulu",
    193,
    240,
    124,
    59,
    202,
    182
  ],
  [
    "C26B03",
    "Indochine",
    194,
    107,
    3,
    23,
    247,
    98
  ],
  [
    "C2955D",
    "Twine",
    194,
    149,
    93,
    23,
    115,
    143
  ],
  [
    "C2BDB6",
    "Cotton Seed",
    194,
    189,
    182,
    24,
    22,
    188
  ],
  [
    "C2CAC4",
    "Pumice",
    194,
    202,
    196,
    95,
    17,
    197
  ],
  [
    "C2E8E5",
    "Jagged Ice",
    194,
    232,
    229,
    124,
    115,
    212
  ],
  [
    "C32148",
    "Maroon Flush",
    195,
    33,
    72,
    -10,
    181,
    113
  ],
  [
    "C3B091",
    "Indian Khaki",
    195,
    176,
    145,
    26,
    74,
    170
  ],
  [
    "C3BFC1",
    "Pale Slate",
    195,
    191,
    193,
    -21,
    8,
    193
  ],
  [
    "C3C3BD",
    "Gray Nickel",
    195,
    195,
    189,
    42,
    12,
    192
  ],
  [
    "C3CDE6",
    "Periwinkle Gray",
    195,
    205,
    230,
    157,
    105,
    212
  ],
  [
    "C3D1D1",
    "Tiara",
    195,
    209,
    209,
    127,
    33,
    202
  ],
  [
    "C3DDF9",
    "Tropical Blue",
    195,
    221,
    249,
    149,
    208,
    222
  ],
  [
    "C41E3A",
    "Cardinal",
    196,
    30,
    58,
    -7,
    187,
    113
  ],
  [
    "C45655",
    "Fuzzy Wuzzy Brown",
    196,
    86,
    85,
    0,
    123,
    140
  ],
  [
    "C45719",
    "Orange Roughy",
    196,
    87,
    25,
    15,
    197,
    110
  ],
  [
    "C4C4BC",
    "Mist Gray",
    196,
    196,
    188,
    42,
    16,
    192
  ],
  [
    "C4D0B0",
    "Coriander",
    196,
    208,
    176,
    58,
    64,
    192
  ],
  [
    "C4F4EB",
    "Mint Tulip",
    196,
    244,
    235,
    119,
    174,
    220
  ],
  [
    "C54B8C",
    "Mulberry",
    197,
    75,
    140,
    -22,
    130,
    136
  ],
  [
    "C59922",
    "Nugget",
    197,
    153,
    34,
    31,
    179,
    115
  ],
  [
    "C5994B",
    "Tussock",
    197,
    153,
    75,
    27,
    130,
    136
  ],
  [
    "C5DBCA",
    "Sea Mist",
    197,
    219,
    202,
    94,
    59,
    208
  ],
  [
    "C5E17A",
    "Yellow Green",
    197,
    225,
    122,
    54,
    161,
    173
  ],
  [
    "C62D42",
    "Brick Red",
    198,
    45,
    66,
    -5,
    160,
    121
  ],
  [
    "C6726B",
    "Contessa",
    198,
    114,
    107,
    3,
    113,
    152
  ],
  [
    "C69191",
    "Oriental Pink",
    198,
    145,
    145,
    0,
    80,
    171
  ],
  [
    "C6A84B",
    "Roti",
    198,
    168,
    75,
    32,
    132,
    136
  ],
  [
    "C6C3B5",
    "Ash",
    198,
    195,
    181,
    34,
    33,
    189
  ],
  [
    "C6C8BD",
    "Kangaroo",
    198,
    200,
    189,
    50,
    23,
    194
  ],
  [
    "C6E610",
    "Las Palmas",
    198,
    230,
    16,
    48,
    221,
    123
  ],
  [
    "C7031E",
    "Monza",
    199,
    3,
    30,
    -5,
    247,
    101
  ],
  [
    "C71585",
    "Red Violet",
    199,
    21,
    133,
    -26,
    206,
    110
  ],
  [
    "C7BCA2",
    "Coral Reef",
    199,
    188,
    162,
    29,
    63,
    180
  ],
  [
    "C7C1FF",
    "Melrose",
    199,
    193,
    255,
    174,
    255,
    224
  ],
  [
    "C7C4BF",
    "Cloud",
    199,
    196,
    191,
    26,
    16,
    195
  ],
  [
    "C7C9D5",
    "Ghost",
    199,
    201,
    213,
    163,
    36,
    206
  ],
  [
    "C7CD90",
    "Pine Glade",
    199,
    205,
    144,
    46,
    96,
    174
  ],
  [
    "C7DDE5",
    "Botticelli",
    199,
    221,
    229,
    138,
    93,
    214
  ],
  [
    "C88A65",
    "Antique Brass",
    200,
    138,
    101,
    15,
    120,
    150
  ],
  [
    "C8A2C8",
    "Lilac",
    200,
    162,
    200,
    -42,
    65,
    180
  ],
  [
    "C8A528",
    "Hokey Pokey",
    200,
    165,
    40,
    33,
    170,
    120
  ],
  [
    "C8AABF",
    "Lily",
    200,
    170,
    191,
    -29,
    54,
    185
  ],
  [
    "C8B568",
    "Laser",
    200,
    181,
    104,
    34,
    118,
    152
  ],
  [
    "C8E3D7",
    "Edgewater",
    200,
    227,
    215,
    108,
    82,
    213
  ],
  [
    "C96323",
    "Piper",
    201,
    99,
    35,
    16,
    179,
    118
  ],
  [
    "C99415",
    "Pizza",
    201,
    148,
    21,
    29,
    206,
    111
  ],
  [
    "C9A0DC",
    "Light Wisteria",
    201,
    160,
    220,
    199,
    117,
    190
  ],
  [
    "C9B29B",
    "Rodeo Dust",
    201,
    178,
    155,
    21,
    76,
    178
  ],
  [
    "C9B35B",
    "Sundance",
    201,
    179,
    91,
    34,
    128,
    146
  ],
  [
    "C9B93B",
    "Earls Green",
    201,
    185,
    59,
    37,
    144,
    130
  ],
  [
    "C9C0BB",
    "Silver Rust",
    201,
    192,
    187,
    15,
    29,
    194
  ],
  [
    "C9D9D2",
    "Conch",
    201,
    217,
    210,
    108,
    44,
    209
  ],
  [
    "C9FFA2",
    "Reef",
    201,
    255,
    162,
    67,
    255,
    208
  ],
  [
    "C9FFE5",
    "Aero Blue",
    201,
    255,
    229,
    107,
    254,
    227
  ],
  [
    "CA3435",
    "Flush Mahogany",
    202,
    52,
    53,
    0,
    150,
    127
  ],
  [
    "CABB48",
    "Turmeric",
    202,
    187,
    72,
    37,
    140,
    137
  ],
  [
    "CADCD4",
    "Paris White",
    202,
    220,
    212,
    108,
    52,
    211
  ],
  [
    "CAE00D",
    "Bitter Lemon",
    202,
    224,
    13,
    46,
    227,
    118
  ],
  [
    "CAE6DA",
    "Skeptic",
    202,
    230,
    218,
    109,
    91,
    216
  ],
  [
    "CB8FA9",
    "Viola",
    203,
    143,
    169,
    -18,
    93,
    173
  ],
  [
    "CBCAB6",
    "Foggy Gray",
    203,
    202,
    182,
    40,
    42,
    192
  ],
  [
    "CBD3B0",
    "Green Mist",
    203,
    211,
    176,
    52,
    72,
    193
  ],
  [
    "CBDBD6",
    "Nebula",
    203,
    219,
    214,
    114,
    46,
    211
  ],
  [
    "CC3333",
    "Persian Red",
    204,
    51,
    51,
    0,
    153,
    127
  ],
  [
    "CC5500",
    "Burnt Orange",
    204,
    85,
    0,
    17,
    255,
    102
  ],
  [
    "CC7722",
    "Ochre",
    204,
    119,
    34,
    21,
    182,
    119
  ],
  [
    "CC8899",
    "Puce",
    204,
    136,
    153,
    -10,
    102,
    170
  ],
  [
    "CCCAA8",
    "Thistle Green",
    204,
    202,
    168,
    40,
    66,
    186
  ],
  [
    "CCCCFF",
    "Periwinkle",
    204,
    204,
    255,
    170,
    255,
    229
  ],
  [
    "CCFF00",
    "Electric Lime",
    204,
    255,
    0,
    50,
    255,
    127
  ],
  [
    "CD5700",
    "Tenn",
    205,
    87,
    0,
    18,
    255,
    102
  ],
  [
    "CD5C5C",
    "Chestnut Rose",
    205,
    92,
    92,
    0,
    135,
    148
  ],
  [
    "CD8429",
    "Brandy Punch",
    205,
    132,
    41,
    23,
    170,
    123
  ],
  [
    "CDF4FF",
    "Onahau",
    205,
    244,
    255,
    136,
    255,
    230
  ],
  [
    "CEB98F",
    "Sorrell Brown",
    206,
    185,
    143,
    28,
    99,
    174
  ],
  [
    "CEBABA",
    "Cold Turkey",
    206,
    186,
    186,
    0,
    43,
    195
  ],
  [
    "CEC291",
    "Yuma",
    206,
    194,
    145,
    34,
    97,
    175
  ],
  [
    "CEC7A7",
    "Chino",
    206,
    199,
    167,
    34,
    72,
    186
  ],
  [
    "CFA39D",
    "Eunry",
    207,
    163,
    157,
    5,
    87,
    182
  ],
  [
    "CFB53B",
    "Old Gold",
    207,
    181,
    59,
    35,
    154,
    133
  ],
  [
    "CFDCCF",
    "Tasman",
    207,
    220,
    207,
    85,
    39,
    213
  ],
  [
    "CFE5D2",
    "Surf Crest",
    207,
    229,
    210,
    90,
    75,
    218
  ],
  [
    "CFF9F3",
    "Humming Bird",
    207,
    249,
    243,
    121,
    198,
    227
  ],
  [
    "CFFAF4",
    "Scandal",
    207,
    250,
    244,
    121,
    206,
    228
  ],
  [
    "D05F04",
    "Red Stage",
    208,
    95,
    4,
    18,
    245,
    105
  ],
  [
    "D06DA1",
    "Hopbush",
    208,
    109,
    161,
    -22,
    130,
    158
  ],
  [
    "D07D12",
    "Meteor",
    208,
    125,
    18,
    23,
    214,
    113
  ],
  [
    "D0BEF8",
    "Perfume",
    208,
    190,
    248,
    183,
    205,
    219
  ],
  [
    "D0C0E5",
    "Prelude",
    208,
    192,
    229,
    188,
    106,
    210
  ],
  [
    "D0F0C0",
    "Tea Green",
    208,
    240,
    192,
    70,
    156,
    216
  ],
  [
    "D18F1B",
    "Geebung",
    209,
    143,
    27,
    27,
    196,
    117
  ],
  [
    "D1BEA8",
    "Vanilla",
    209,
    190,
    168,
    22,
    78,
    188
  ],
  [
    "D1C6B4",
    "Soft Amber",
    209,
    198,
    180,
    26,
    61,
    194
  ],
  [
    "D1D2CA",
    "Celeste",
    209,
    210,
    202,
    47,
    20,
    206
  ],
  [
    "D1D2DD",
    "Mischka",
    209,
    210,
    221,
    166,
    38,
    215
  ],
  [
    "D1E231",
    "Pear",
    209,
    226,
    49,
    46,
    192,
    137
  ],
  [
    "D2691E",
    "Hot Cinnamon",
    210,
    105,
    30,
    17,
    191,
    120
  ],
  [
    "D27D46",
    "Raw Sienna",
    210,
    125,
    70,
    16,
    155,
    140
  ],
  [
    "D29EAA",
    "Careys Pink",
    210,
    158,
    170,
    -9,
    93,
    184
  ],
  [
    "D2B48C",
    "Tan",
    210,
    180,
    140,
    24,
    111,
    175
  ],
  [
    "D2DA97",
    "Deco",
    210,
    218,
    151,
    47,
    121,
    184
  ],
  [
    "D2F6DE",
    "Blue Romance",
    210,
    246,
    222,
    99,
    169,
    227
  ],
  [
    "D2F8B0",
    "Gossip",
    210,
    248,
    176,
    64,
    213,
    211
  ],
  [
    "D3CBBA",
    "Sisal",
    211,
    203,
    186,
    28,
    56,
    198
  ],
  [
    "D3CDC5",
    "Swirl",
    211,
    205,
    197,
    24,
    34,
    204
  ],
  [
    "D47494",
    "Charm",
    212,
    116,
    148,
    -14,
    134,
    164
  ],
  [
    "D4B6AF",
    "Clam Shell",
    212,
    182,
    175,
    8,
    76,
    193
  ],
  [
    "D4BF8D",
    "Straw",
    212,
    191,
    141,
    29,
    115,
    176
  ],
  [
    "D4C4A8",
    "Akaroa",
    212,
    196,
    168,
    27,
    86,
    190
  ],
  [
    "D4CD16",
    "Bird Flower",
    212,
    205,
    22,
    40,
    207,
    117
  ],
  [
    "D4D7D9",
    "Iron",
    212,
    215,
    217,
    144,
    15,
    214
  ],
  [
    "D4DFE2",
    "Geyser",
    212,
    223,
    226,
    136,
    49,
    219
  ],
  [
    "D4E2FC",
    "Hawkes Blue",
    212,
    226,
    252,
    155,
    221,
    232
  ],
  [
    "D54600",
    "Grenadier",
    213,
    70,
    0,
    13,
    255,
    106
  ],
  [
    "D591A4",
    "Can Can",
    213,
    145,
    164,
    -11,
    114,
    179
  ],
  [
    "D59A6F",
    "Whiskey",
    213,
    154,
    111,
    17,
    139,
    162
  ],
  [
    "D5D195",
    "Winter Hazel",
    213,
    209,
    149,
    39,
    110,
    181
  ],
  [
    "D5F6E3",
    "Granny Apple",
    213,
    246,
    227,
    103,
    165,
    229
  ],
  [
    "D69188",
    "My Pink",
    214,
    145,
    136,
    4,
    124,
    175
  ],
  [
    "D6C562",
    "Tacha",
    214,
    197,
    98,
    36,
    149,
    156
  ],
  [
    "D6CEF6",
    "Moon Raker",
    214,
    206,
    246,
    178,
    175,
    226
  ],
  [
    "D6D6D1",
    "Quill Gray",
    214,
    214,
    209,
    42,
    14,
    211
  ],
  [
    "D6FFDB",
    "Snowy Mint",
    214,
    255,
    219,
    90,
    255,
    234
  ],
  [
    "D7837F",
    "New York Pink",
    215,
    131,
    127,
    1,
    133,
    171
  ],
  [
    "D7C498",
    "Pavlova",
    215,
    196,
    152,
    29,
    112,
    183
  ],
  [
    "D7D0FF",
    "Fog",
    215,
    208,
    255,
    176,
    255,
    231
  ],
  [
    "D84437",
    "Valencia",
    216,
    68,
    55,
    3,
    171,
    135
  ],
  [
    "D87C63",
    "Japonica",
    216,
    124,
    99,
    9,
    153,
    157
  ],
  [
    "D8BFD8",
    "Thistle",
    216,
    191,
    216,
    -42,
    61,
    203
  ],
  [
    "D8C2D5",
    "Maverick",
    216,
    194,
    213,
    -36,
    56,
    205
  ],
  [
    "D8FCFA",
    "Foam",
    216,
    252,
    250,
    125,
    218,
    234
  ],
  [
    "D94972",
    "Cabaret",
    217,
    73,
    114,
    -12,
    166,
    145
  ],
  [
    "D99376",
    "Burning Sand",
    217,
    147,
    118,
    12,
    144,
    167
  ],
  [
    "D9B99B",
    "Cameo",
    217,
    185,
    155,
    20,
    114,
    186
  ],
  [
    "D9D6CF",
    "Timberwolf",
    217,
    214,
    207,
    29,
    29,
    211
  ],
  [
    "D9DCC1",
    "Tana",
    217,
    220,
    193,
    47,
    70,
    206
  ],
  [
    "D9E4F5",
    "Link Water",
    217,
    228,
    245,
    153,
    148,
    231
  ],
  [
    "D9F7FF",
    "Mabel",
    217,
    247,
    255,
    136,
    255,
    236
  ],
  [
    "DA3287",
    "Cerise",
    218,
    50,
    135,
    -21,
    177,
    134
  ],
  [
    "DA5B38",
    "Flame Pea",
    218,
    91,
    56,
    9,
    175,
    137
  ],
  [
    "DA6304",
    "Bamboo",
    218,
    99,
    4,
    18,
    245,
    111
  ],
  [
    "DA6A41",
    "Red Damask",
    218,
    106,
    65,
    11,
    171,
    141
  ],
  [
    "DA70D6",
    "Orchid",
    218,
    112,
    214,
    -40,
    150,
    164
  ],
  [
    "DA8A67",
    "Copperfield",
    218,
    138,
    103,
    12,
    155,
    160
  ],
  [
    "DAA520",
    "Golden Grass",
    218,
    165,
    32,
    30,
    189,
    125
  ],
  [
    "DAECD6",
    "Zanah",
    218,
    236,
    214,
    77,
    93,
    225
  ],
  [
    "DAF4F0",
    "Iceberg",
    218,
    244,
    240,
    120,
    138,
    231
  ],
  [
    "DAFAFF",
    "Oyster Bay",
    218,
    250,
    255,
    133,
    255,
    236
  ],
  [
    "DB5079",
    "Cranberry",
    219,
    80,
    121,
    -12,
    167,
    149
  ],
  [
    "DB9690",
    "Petite Orchid",
    219,
    150,
    144,
    3,
    130,
    181
  ],
  [
    "DB995E",
    "Di Serria",
    219,
    153,
    94,
    20,
    161,
    156
  ],
  [
    "DBDBDB",
    "Alto",
    219,
    219,
    219,
    0,
    0,
    219
  ],
  [
    "DBFFF8",
    "Frosted Mint",
    219,
    255,
    248,
    119,
    255,
    237
  ],
  [
    "DC143C",
    "Crimson",
    220,
    20,
    60,
    -8,
    212,
    120
  ],
  [
    "DC4333",
    "Punch",
    220,
    67,
    51,
    4,
    180,
    135
  ],
  [
    "DCB20C",
    "Galliano",
    220,
    178,
    12,
    33,
    228,
    116
  ],
  [
    "DCB4BC",
    "Blossom",
    220,
    180,
    188,
    -8,
    92,
    200
  ],
  [
    "DCD747",
    "Wattle",
    220,
    215,
    71,
    41,
    173,
    145
  ],
  [
    "DCD9D2",
    "Westar",
    220,
    217,
    210,
    29,
    31,
    215
  ],
  [
    "DCDDCC",
    "Moon Mist",
    220,
    221,
    204,
    44,
    51,
    212
  ],
  [
    "DCEDB4",
    "Caper",
    220,
    237,
    180,
    55,
    156,
    208
  ],
  [
    "DCF0EA",
    "Swans Down",
    220,
    240,
    234,
    114,
    101,
    230
  ],
  [
    "DDD6D5",
    "Swiss Coffee",
    221,
    214,
    213,
    5,
    26,
    217
  ],
  [
    "DDF9F1",
    "White Ice",
    221,
    249,
    241,
    115,
    178,
    235
  ],
  [
    "DE3163",
    "Cerise Red",
    222,
    49,
    99,
    -12,
    184,
    135
  ],
  [
    "DE6360",
    "Roman",
    222,
    99,
    96,
    1,
    167,
    159
  ],
  [
    "DEA681",
    "Tumbleweed",
    222,
    166,
    129,
    16,
    149,
    175
  ],
  [
    "DEBA13",
    "Gold Tips",
    222,
    186,
    19,
    34,
    214,
    120
  ],
  [
    "DEC196",
    "Brandy",
    222,
    193,
    150,
    25,
    133,
    186
  ],
  [
    "DECBC6",
    "Wafer",
    222,
    203,
    198,
    8,
    67,
    210
  ],
  [
    "DED4A4",
    "Sapling",
    222,
    212,
    164,
    35,
    119,
    193
  ],
  [
    "DED717",
    "Barberry",
    222,
    215,
    23,
    41,
    207,
    122
  ],
  [
    "DEE5C0",
    "Beryl Green",
    222,
    229,
    192,
    50,
    106,
    210
  ],
  [
    "DEF5FF",
    "Pattens Blue",
    222,
    245,
    255,
    140,
    255,
    238
  ],
  [
    "DF73FF",
    "Heliotrope",
    223,
    115,
    255,
    202,
    255,
    185
  ],
  [
    "DFBE6F",
    "Apache",
    223,
    190,
    111,
    29,
    162,
    167
  ],
  [
    "DFCD6F",
    "Chenin",
    223,
    205,
    111,
    35,
    162,
    167
  ],
  [
    "DFCFDB",
    "Lola",
    223,
    207,
    219,
    -31,
    51,
    215
  ],
  [
    "DFECDA",
    "Willow Brook",
    223,
    236,
    218,
    73,
    81,
    227
  ],
  [
    "DFFF00",
    "Chartreuse Yellow",
    223,
    255,
    0,
    47,
    255,
    127
  ],
  [
    "E0B0FF",
    "Mauve",
    224,
    176,
    255,
    195,
    255,
    215
  ],
  [
    "E0B646",
    "Anzac",
    224,
    182,
    70,
    30,
    181,
    147
  ],
  [
    "E0B974",
    "Harvest Gold",
    224,
    185,
    116,
    27,
    162,
    170
  ],
  [
    "E0C095",
    "Calico",
    224,
    192,
    149,
    24,
    139,
    186
  ],
  [
    "E0FFFF",
    "Baby Blue",
    224,
    255,
    255,
    127,
    255,
    239
  ],
  [
    "E16865",
    "Sunglo",
    225,
    104,
    101,
    1,
    171,
    163
  ],
  [
    "E1BC64",
    "Equator",
    225,
    188,
    100,
    29,
    172,
    162
  ],
  [
    "E1C0C8",
    "Pink Flare",
    225,
    192,
    200,
    -10,
    90,
    208
  ],
  [
    "E1E6D6",
    "Periglacial Blue",
    225,
    230,
    214,
    55,
    61,
    222
  ],
  [
    "E1EAD4",
    "Kidnapper",
    225,
    234,
    212,
    59,
    87,
    223
  ],
  [
    "E1F6E8",
    "Tara",
    225,
    246,
    232,
    99,
    137,
    235
  ],
  [
    "E25465",
    "Mandy",
    226,
    84,
    101,
    -5,
    181,
    155
  ],
  [
    "E2725B",
    "Terracotta",
    226,
    114,
    91,
    7,
    178,
    158
  ],
  [
    "E28913",
    "Golden Bell",
    226,
    137,
    19,
    24,
    215,
    122
  ],
  [
    "E292C0",
    "Shocking",
    226,
    146,
    192,
    -24,
    147,
    186
  ],
  [
    "E29418",
    "Dixie",
    226,
    148,
    24,
    26,
    206,
    125
  ],
  [
    "E29CD2",
    "Light Orchid",
    226,
    156,
    210,
    -32,
    139,
    191
  ],
  [
    "E2D8ED",
    "Snuff",
    226,
    216,
    237,
    190,
    93,
    226
  ],
  [
    "E2EBED",
    "Mystic",
    226,
    235,
    237,
    135,
    59,
    231
  ],
  [
    "E2F3EC",
    "Apple Green",
    226,
    243,
    236,
    110,
    105,
    234
  ],
  [
    "E30B5C",
    "Razzmatazz",
    227,
    11,
    92,
    -15,
    231,
    118
  ],
  [
    "E32636",
    "Alizarin Crimson",
    227,
    38,
    54,
    -3,
    196,
    132
  ],
  [
    "E34234",
    "Cinnabar",
    227,
    66,
    52,
    3,
    193,
    139
  ],
  [
    "E3BEBE",
    "Cavern Pink",
    227,
    190,
    190,
    0,
    101,
    208
  ],
  [
    "E3F5E1",
    "Peppermint",
    227,
    245,
    225,
    80,
    127,
    235
  ],
  [
    "E3F988",
    "Mindaro",
    227,
    249,
    136,
    50,
    230,
    192
  ],
  [
    "E47698",
    "Deep Blush",
    228,
    118,
    152,
    -13,
    171,
    173
  ],
  [
    "E49B0F",
    "Gamboge",
    228,
    155,
    15,
    27,
    223,
    121
  ],
  [
    "E4C2D5",
    "Melanie",
    228,
    194,
    213,
    -23,
    98,
    211
  ],
  [
    "E4CFDE",
    "Twilight",
    228,
    207,
    222,
    -30,
    71,
    217
  ],
  [
    "E4D1C0",
    "Bone",
    228,
    209,
    192,
    20,
    102,
    210
  ],
  [
    "E4D422",
    "Sunflower",
    228,
    212,
    34,
    38,
    199,
    131
  ],
  [
    "E4D5B7",
    "Grain Brown",
    228,
    213,
    183,
    28,
    115,
    205
  ],
  [
    "E4D69B",
    "Zombie",
    228,
    214,
    155,
    34,
    146,
    191
  ],
  [
    "E4F6E7",
    "Frostee",
    228,
    246,
    231,
    92,
    127,
    237
  ],
  [
    "E4FFD1",
    "Snow Flurry",
    228,
    255,
    209,
    67,
    255,
    232
  ],
  [
    "E52B50",
    "Amaranth",
    229,
    43,
    80,
    -8,
    199,
    136
  ],
  [
    "E5841B",
    "Zest",
    229,
    132,
    27,
    22,
    202,
    128
  ],
  [
    "E5CCC9",
    "Dust Storm",
    229,
    204,
    201,
    4,
    89,
    215
  ],
  [
    "E5D7BD",
    "Stark White",
    229,
    215,
    189,
    27,
    110,
    209
  ],
  [
    "E5D8AF",
    "Hampton",
    229,
    216,
    175,
    32,
    129,
    202
  ],
  [
    "E5E0E1",
    "Bon Jour",
    229,
    224,
    225,
    -8,
    22,
    226
  ],
  [
    "E5E5E5",
    "Mercury",
    229,
    229,
    229,
    0,
    0,
    229
  ],
  [
    "E5F9F6",
    "Polar",
    229,
    249,
    246,
    121,
    159,
    239
  ],
  [
    "E64E03",
    "Trinidad",
    230,
    78,
    3,
    14,
    248,
    116
  ],
  [
    "E6BE8A",
    "Gold Sand",
    230,
    190,
    138,
    24,
    165,
    184
  ],
  [
    "E6BEA5",
    "Cashmere",
    230,
    190,
    165,
    16,
    144,
    197
  ],
  [
    "E6D7B9",
    "Double Spanish White",
    230,
    215,
    185,
    28,
    120,
    207
  ],
  [
    "E6E4D4",
    "Satin Linen",
    230,
    228,
    212,
    37,
    67,
    221
  ],
  [
    "E6F2EA",
    "Harp",
    230,
    242,
    234,
    99,
    80,
    236
  ],
  [
    "E6F8F3",
    "Off Green",
    230,
    248,
    243,
    115,
    143,
    239
  ],
  [
    "E6FFE9",
    "Hint of Green",
    230,
    255,
    233,
    90,
    254,
    242
  ],
  [
    "E6FFFF",
    "Tranquil",
    230,
    255,
    255,
    127,
    254,
    242
  ],
  [
    "E77200",
    "Mango Tango",
    231,
    114,
    0,
    20,
    255,
    115
  ],
  [
    "E7730A",
    "Christine",
    231,
    115,
    10,
    20,
    233,
    120
  ],
  [
    "E79F8C",
    "Tonys Pink",
    231,
    159,
    140,
    8,
    166,
    185
  ],
  [
    "E79FC4",
    "Kobi",
    231,
    159,
    196,
    -21,
    152,
    195
  ],
  [
    "E7BCB4",
    "Rose Fog",
    231,
    188,
    180,
    6,
    131,
    205
  ],
  [
    "E7BF05",
    "Corn",
    231,
    191,
    5,
    34,
    244,
    118
  ],
  [
    "E7CD8C",
    "Putty",
    231,
    205,
    140,
    30,
    166,
    185
  ],
  [
    "E7ECE6",
    "Gray Nurse",
    231,
    236,
    230,
    77,
    34,
    233
  ],
  [
    "E7F8FF",
    "Lily White",
    231,
    248,
    255,
    139,
    254,
    243
  ],
  [
    "E7FEFF",
    "Bubbles",
    231,
    254,
    255,
    129,
    254,
    243
  ],
  [
    "E89928",
    "Fire Bush",
    232,
    153,
    40,
    25,
    205,
    136
  ],
  [
    "E8B9B3",
    "Shilo",
    232,
    185,
    179,
    4,
    136,
    205
  ],
  [
    "E8E0D5",
    "Pearl Bush",
    232,
    224,
    213,
    24,
    74,
    222
  ],
  [
    "E8EBE0",
    "Green White",
    232,
    235,
    224,
    54,
    54,
    229
  ],
  [
    "E8F1D4",
    "Chrome White",
    232,
    241,
    212,
    55,
    129,
    226
  ],
  [
    "E8F2EB",
    "Gin",
    232,
    242,
    235,
    97,
    70,
    237
  ],
  [
    "E8F5F2",
    "Aqua Squeeze",
    232,
    245,
    242,
    117,
    100,
    238
  ],
  [
    "E96E00",
    "Clementine",
    233,
    110,
    0,
    20,
    255,
    116
  ],
  [
    "E97451",
    "Burnt Sienna",
    233,
    116,
    81,
    9,
    197,
    157
  ],
  [
    "E97C07",
    "Tahiti Gold",
    233,
    124,
    7,
    22,
    240,
    120
  ],
  [
    "E9CECD",
    "Oyster Pink",
    233,
    206,
    205,
    1,
    99,
    219
  ],
  [
    "E9D75A",
    "Confetti",
    233,
    215,
    90,
    37,
    195,
    161
  ],
  [
    "E9E3E3",
    "Ebb",
    233,
    227,
    227,
    0,
    30,
    229
  ],
  [
    "E9F8ED",
    "Ottoman",
    233,
    248,
    237,
    96,
    131,
    240
  ],
  [
    "E9FFFD",
    "Clear Day",
    233,
    255,
    253,
    123,
    254,
    243
  ],
  [
    "EA88A8",
    "Carissma",
    234,
    136,
    168,
    -13,
    178,
    185
  ],
  [
    "EAAE69",
    "Porsche",
    234,
    174,
    105,
    22,
    192,
    169
  ],
  [
    "EAB33B",
    "Tulip Tree",
    234,
    179,
    59,
    29,
    205,
    146
  ],
  [
    "EAC674",
    "Rob Roy",
    234,
    198,
    116,
    29,
    188,
    175
  ],
  [
    "EADAB8",
    "Raffia",
    234,
    218,
    184,
    28,
    138,
    209
  ],
  [
    "EAE8D4",
    "White Rock",
    234,
    232,
    212,
    38,
    87,
    223
  ],
  [
    "EAF6EE",
    "Panache",
    234,
    246,
    238,
    99,
    102,
    240
  ],
  [
    "EAF6FF",
    "Solitude",
    234,
    246,
    255,
    145,
    254,
    244
  ],
  [
    "EAF9F5",
    "Aqua Spring",
    234,
    249,
    245,
    116,
    141,
    241
  ],
  [
    "EAFFFE",
    "Dew",
    234,
    255,
    254,
    125,
    254,
    244
  ],
  [
    "EB9373",
    "Apricot",
    235,
    147,
    115,
    11,
    191,
    175
  ],
  [
    "EBC2AF",
    "Zinnwaldite",
    235,
    194,
    175,
    13,
    153,
    205
  ],
  [
    "ECA927",
    "Fuel Yellow",
    236,
    169,
    39,
    28,
    213,
    137
  ],
  [
    "ECC54E",
    "Ronchi",
    236,
    197,
    78,
    32,
    205,
    157
  ],
  [
    "ECC7EE",
    "French Lilac",
    236,
    199,
    238,
    210,
    136,
    218
  ],
  [
    "ECCDB9",
    "Just Right",
    236,
    205,
    185,
    16,
    146,
    210
  ],
  [
    "ECE090",
    "Wild Rice",
    236,
    224,
    144,
    36,
    180,
    190
  ],
  [
    "ECEBBD",
    "Fall Green",
    236,
    235,
    189,
    41,
    141,
    212
  ],
  [
    "ECEBCE",
    "Aths Special",
    236,
    235,
    206,
    41,
    112,
    221
  ],
  [
    "ECF245",
    "Starship",
    236,
    242,
    69,
    43,
    221,
    155
  ],
  [
    "ED0A3F",
    "Red Ribbon",
    237,
    10,
    63,
    -9,
    234,
    123
  ],
  [
    "ED7A1C",
    "Tango",
    237,
    122,
    28,
    19,
    217,
    132
  ],
  [
    "ED9121",
    "Carrot Orange",
    237,
    145,
    33,
    23,
    216,
    135
  ],
  [
    "ED989E",
    "Sea Pink",
    237,
    152,
    158,
    -3,
    179,
    194
  ],
  [
    "EDB381",
    "Tacao",
    237,
    179,
    129,
    19,
    191,
    183
  ],
  [
    "EDC9AF",
    "Desert Sand",
    237,
    201,
    175,
    17,
    161,
    206
  ],
  [
    "EDCDAB",
    "Pancho",
    237,
    205,
    171,
    21,
    165,
    204
  ],
  [
    "EDDCB1",
    "Chamois",
    237,
    220,
    177,
    30,
    159,
    207
  ],
  [
    "EDEA99",
    "Primrose",
    237,
    234,
    153,
    40,
    178,
    195
  ],
  [
    "EDF5DD",
    "Frost",
    237,
    245,
    221,
    56,
    139,
    233
  ],
  [
    "EDF5F5",
    "Aqua Haze",
    237,
    245,
    245,
    127,
    72,
    241
  ],
  [
    "EDF6FF",
    "Zumthor",
    237,
    246,
    255,
    148,
    255,
    246
  ],
  [
    "EDF9F1",
    "Narvik",
    237,
    249,
    241,
    99,
    127,
    243
  ],
  [
    "EDFC84",
    "Honeysuckle",
    237,
    252,
    132,
    47,
    242,
    192
  ],
  [
    "EE82EE",
    "Lavender Magenta",
    238,
    130,
    238,
    -42,
    193,
    184
  ],
  [
    "EEC1BE",
    "Beauty Bush",
    238,
    193,
    190,
    2,
    149,
    214
  ],
  [
    "EED794",
    "Chalky",
    238,
    215,
    148,
    31,
    185,
    193
  ],
  [
    "EED9C4",
    "Almond",
    238,
    217,
    196,
    21,
    140,
    217
  ],
  [
    "EEDC82",
    "Flax",
    238,
    220,
    130,
    35,
    193,
    184
  ],
  [
    "EEDEDA",
    "Bizarre",
    238,
    222,
    218,
    8,
    94,
    227
  ],
  [
    "EEE3AD",
    "Double Colonial White",
    238,
    227,
    173,
    35,
    167,
    205
  ],
  [
    "EEEEE8",
    "Cararra",
    238,
    238,
    232,
    42,
    38,
    235
  ],
  [
    "EEEF78",
    "Manz",
    238,
    239,
    120,
    42,
    200,
    179
  ],
  [
    "EEF0C8",
    "Tahuna Sands",
    238,
    240,
    200,
    44,
    145,
    220
  ],
  [
    "EEF0F3",
    "Athens Gray",
    238,
    240,
    243,
    153,
    43,
    240
  ],
  [
    "EEF3C3",
    "Tusk",
    238,
    243,
    195,
    46,
    169,
    219
  ],
  [
    "EEF4DE",
    "Loafer",
    238,
    244,
    222,
    54,
    127,
    233
  ],
  [
    "EEF6F7",
    "Catskill White",
    238,
    246,
    247,
    132,
    91,
    242
  ],
  [
    "EEFDFF",
    "Twilight Blue",
    238,
    253,
    255,
    132,
    255,
    246
  ],
  [
    "EEFF9A",
    "Jonquil",
    238,
    255,
    154,
    49,
    255,
    204
  ],
  [
    "EEFFE2",
    "Rice Flower",
    238,
    255,
    226,
    67,
    255,
    240
  ],
  [
    "EF863F",
    "Jaffa",
    239,
    134,
    63,
    17,
    215,
    151
  ],
  [
    "EFEFEF",
    "Gallery",
    239,
    239,
    239,
    0,
    0,
    239
  ],
  [
    "EFF2F3",
    "Porcelain",
    239,
    242,
    243,
    138,
    36,
    241
  ],
  [
    "F091A9",
    "Mauvelous",
    240,
    145,
    169,
    -10,
    193,
    192
  ],
  [
    "F0D52D",
    "Golden Dream",
    240,
    213,
    45,
    36,
    220,
    142
  ],
  [
    "F0DB7D",
    "Golden Sand",
    240,
    219,
    125,
    34,
    202,
    182
  ],
  [
    "F0DC82",
    "Buff",
    240,
    220,
    130,
    34,
    200,
    185
  ],
  [
    "F0E2EC",
    "Prim",
    240,
    226,
    236,
    -30,
    81,
    233
  ],
  [
    "F0E68C",
    "Khaki",
    240,
    230,
    140,
    38,
    196,
    190
  ],
  [
    "F0EEFD",
    "Selago",
    240,
    238,
    253,
    175,
    201,
    245
  ],
  [
    "F0EEFF",
    "Titan White",
    240,
    238,
    255,
    174,
    255,
    246
  ],
  [
    "F0F8FF",
    "Alice Blue",
    240,
    248,
    255,
    147,
    255,
    247
  ],
  [
    "F0FCEA",
    "Feta",
    240,
    252,
    234,
    70,
    191,
    243
  ],
  [
    "F18200",
    "Gold Drop",
    241,
    130,
    0,
    22,
    255,
    120
  ],
  [
    "F19BAB",
    "Wewak",
    241,
    155,
    171,
    -7,
    192,
    197
  ],
  [
    "F1E788",
    "Sahara Sand",
    241,
    231,
    136,
    38,
    201,
    188
  ],
  [
    "F1E9D2",
    "Parchment",
    241,
    233,
    210,
    31,
    133,
    225
  ],
  [
    "F1E9FF",
    "Blue Chalk",
    241,
    233,
    255,
    185,
    254,
    243
  ],
  [
    "F1EEC1",
    "Mint Julep",
    241,
    238,
    193,
    39,
    161,
    217
  ],
  [
    "F1F1F1",
    "Seashell",
    241,
    241,
    241,
    0,
    0,
    241
  ],
  [
    "F1F7F2",
    "Saltpan",
    241,
    247,
    242,
    92,
    69,
    243
  ],
  [
    "F1FFAD",
    "Tidal",
    241,
    255,
    173,
    49,
    255,
    214
  ],
  [
    "F1FFC8",
    "Chiffon",
    241,
    255,
    200,
    53,
    254,
    227
  ],
  [
    "F2552A",
    "Flamingo",
    242,
    85,
    42,
    9,
    225,
    142
  ],
  [
    "F28500",
    "Tangerine",
    242,
    133,
    0,
    23,
    255,
    121
  ],
  [
    "F2C3B2",
    "Mandys Pink",
    242,
    195,
    178,
    11,
    181,
    210
  ],
  [
    "F2F2F2",
    "Concrete",
    242,
    242,
    242,
    0,
    0,
    242
  ],
  [
    "F2FAFA",
    "Black Squeeze",
    242,
    250,
    250,
    127,
    113,
    245
  ],
  [
    "F34723",
    "Pomegranate",
    243,
    71,
    35,
    7,
    228,
    139
  ],
  [
    "F3AD16",
    "Buttercup",
    243,
    173,
    22,
    29,
    230,
    132
  ],
  [
    "F3D69D",
    "New Orleans",
    243,
    214,
    157,
    28,
    199,
    200
  ],
  [
    "F3D9DF",
    "Vanilla Ice",
    243,
    217,
    223,
    -9,
    132,
    229
  ],
  [
    "F3E7BB",
    "Sidecar",
    243,
    231,
    187,
    33,
    178,
    214
  ],
  [
    "F3E9E5",
    "Dawn Pink",
    243,
    233,
    229,
    12,
    93,
    236
  ],
  [
    "F3EDCF",
    "Wheatfield",
    243,
    237,
    207,
    35,
    152,
    225
  ],
  [
    "F3FB62",
    "Canary",
    243,
    251,
    98,
    44,
    242,
    174
  ],
  [
    "F3FBD4",
    "Orinoco",
    243,
    251,
    212,
    51,
    211,
    231
  ],
  [
    "F3FFD8",
    "Carla",
    243,
    255,
    216,
    55,
    255,
    235
  ],
  [
    "F400A1",
    "Hollywood Cerise",
    244,
    0,
    161,
    -28,
    255,
    122
  ],
  [
    "F4A460",
    "Sandy brown",
    244,
    164,
    96,
    19,
    222,
    170
  ],
  [
    "F4C430",
    "Saffron",
    244,
    196,
    48,
    32,
    229,
    146
  ],
  [
    "F4D81C",
    "Ripe Lemon",
    244,
    216,
    28,
    36,
    231,
    136
  ],
  [
    "F4EBD3",
    "Janna",
    244,
    235,
    211,
    30,
    153,
    227
  ],
  [
    "F4F2EE",
    "Pampas",
    244,
    242,
    238,
    28,
    54,
    241
  ],
  [
    "F4F4F4",
    "Wild Sand",
    244,
    244,
    244,
    0,
    0,
    244
  ],
  [
    "F4F8FF",
    "Zircon",
    244,
    248,
    255,
    154,
    255,
    249
  ],
  [
    "F57584",
    "Froly",
    245,
    117,
    132,
    -4,
    220,
    181
  ],
  [
    "F5C85C",
    "Cream Can",
    245,
    200,
    92,
    29,
    225,
    168
  ],
  [
    "F5C999",
    "Manhattan",
    245,
    201,
    153,
    22,
    209,
    199
  ],
  [
    "F5D5A0",
    "Maize",
    245,
    213,
    160,
    26,
    206,
    202
  ],
  [
    "F5DEB3",
    "Wheat",
    245,
    222,
    179,
    27,
    195,
    211
  ],
  [
    "F5E7A2",
    "Sandwisp",
    245,
    231,
    162,
    35,
    205,
    203
  ],
  [
    "F5E7E2",
    "Pot Pourri",
    245,
    231,
    226,
    11,
    124,
    235
  ],
  [
    "F5E9D3",
    "Albescent White",
    245,
    233,
    211,
    27,
    160,
    227
  ],
  [
    "F5EDEF",
    "Soft Peach",
    245,
    237,
    239,
    -10,
    72,
    241
  ],
  [
    "F5F3E5",
    "Ecru White",
    245,
    243,
    229,
    37,
    113,
    237
  ],
  [
    "F5F5DC",
    "Beige",
    245,
    245,
    220,
    42,
    141,
    232
  ],
  [
    "F5FB3D",
    "Golden Fizz",
    245,
    251,
    61,
    43,
    244,
    155
  ],
  [
    "F5FFBE",
    "Australian Mint",
    245,
    255,
    190,
    49,
    255,
    222
  ],
  [
    "F64A8A",
    "French Rose",
    246,
    74,
    138,
    -15,
    230,
    160
  ],
  [
    "F653A6",
    "Brilliant Rose",
    246,
    83,
    166,
    -21,
    229,
    164
  ],
  [
    "F6A4C9",
    "Illusion",
    246,
    164,
    201,
    -19,
    209,
    205
  ],
  [
    "F6F0E6",
    "Merino",
    246,
    240,
    230,
    26,
    120,
    238
  ],
  [
    "F6F7F7",
    "Black Haze",
    246,
    247,
    247,
    127,
    14,
    246
  ],
  [
    "F6FFDC",
    "Spring Sun",
    246,
    255,
    220,
    53,
    255,
    237
  ],
  [
    "F7468A",
    "Violet Red",
    247,
    70,
    138,
    -16,
    233,
    158
  ],
  [
    "F77703",
    "Chilean Fire",
    247,
    119,
    3,
    20,
    248,
    125
  ],
  [
    "F77FBE",
    "Persian Pink",
    247,
    127,
    190,
    -22,
    225,
    187
  ],
  [
    "F7B668",
    "Rajah",
    247,
    182,
    104,
    23,
    229,
    175
  ],
  [
    "F7C8DA",
    "Azalea",
    247,
    200,
    218,
    -16,
    190,
    223
  ],
  [
    "F7DBE6",
    "We Peep",
    247,
    219,
    230,
    -16,
    162,
    233
  ],
  [
    "F7F2E1",
    "Quarter Spanish White",
    247,
    242,
    225,
    32,
    147,
    236
  ],
  [
    "F7F5FA",
    "Whisper",
    247,
    245,
    250,
    187,
    84,
    247
  ],
  [
    "F7FAF7",
    "Snow Drift",
    247,
    250,
    247,
    85,
    58,
    248
  ],
  [
    "F8B853",
    "Casablanca",
    248,
    184,
    83,
    26,
    235,
    165
  ],
  [
    "F8C3DF",
    "Chantilly",
    248,
    195,
    223,
    -22,
    201,
    221
  ],
  [
    "F8D9E9",
    "Cherub",
    248,
    217,
    233,
    -21,
    175,
    232
  ],
  [
    "F8DB9D",
    "Marzipan",
    248,
    219,
    157,
    28,
    221,
    202
  ],
  [
    "F8DD5C",
    "Energy Yellow",
    248,
    221,
    92,
    35,
    234,
    170
  ],
  [
    "F8E4BF",
    "Givry",
    248,
    228,
    191,
    27,
    204,
    219
  ],
  [
    "F8F0E8",
    "White Linen",
    248,
    240,
    232,
    21,
    135,
    240
  ],
  [
    "F8F4FF",
    "Magnolia",
    248,
    244,
    255,
    185,
    255,
    249
  ],
  [
    "F8F6F1",
    "Spring Wood",
    248,
    246,
    241,
    30,
    84,
    244
  ],
  [
    "F8F7DC",
    "Coconut Cream",
    248,
    247,
    220,
    40,
    170,
    234
  ],
  [
    "F8F7FC",
    "White Lilac",
    248,
    247,
    252,
    178,
    115,
    249
  ],
  [
    "F8F8F7",
    "Desert Storm",
    248,
    248,
    247,
    42,
    16,
    247
  ],
  [
    "F8F99C",
    "Texas",
    248,
    249,
    156,
    42,
    225,
    202
  ],
  [
    "F8FACD",
    "Corn Field",
    248,
    250,
    205,
    44,
    208,
    227
  ],
  [
    "F8FDD3",
    "Mimosa",
    248,
    253,
    211,
    47,
    232,
    232
  ],
  [
    "F95A61",
    "Carnation",
    249,
    90,
    97,
    -1,
    237,
    169
  ],
  [
    "F9BF58",
    "Saffron Mango",
    249,
    191,
    88,
    27,
    237,
    168
  ],
  [
    "F9E0ED",
    "Carousel Pink",
    249,
    224,
    237,
    -22,
    172,
    236
  ],
  [
    "F9E4BC",
    "Dairy Cream",
    249,
    228,
    188,
    27,
    213,
    218
  ],
  [
    "F9E663",
    "Portica",
    249,
    230,
    99,
    37,
    236,
    174
  ],
  [
    "F9EAF3",
    "Amour",
    249,
    234,
    243,
    -25,
    141,
    241
  ],
  [
    "F9F8E4",
    "Rum Swizzle",
    249,
    248,
    228,
    40,
    162,
    238
  ],
  [
    "F9FF8B",
    "Dolly",
    249,
    255,
    139,
    44,
    254,
    196
  ],
  [
    "F9FFF6",
    "Sugar Cane",
    249,
    255,
    246,
    70,
    255,
    250
  ],
  [
    "FA7814",
    "Ecstasy",
    250,
    120,
    20,
    18,
    244,
    135
  ],
  [
    "FA9D5A",
    "Tan Hide",
    250,
    157,
    90,
    17,
    239,
    170
  ],
  [
    "FAD3A2",
    "Corvette",
    250,
    211,
    162,
    23,
    228,
    206
  ],
  [
    "FADFAD",
    "Peach Yellow",
    250,
    223,
    173,
    27,
    225,
    211
  ],
  [
    "FAE600",
    "Turbo",
    250,
    230,
    0,
    39,
    255,
    125
  ],
  [
    "FAEAB9",
    "Astra",
    250,
    234,
    185,
    32,
    220,
    217
  ],
  [
    "FAECCC",
    "Champagne",
    250,
    236,
    204,
    29,
    209,
    227
  ],
  [
    "FAF0E6",
    "Linen",
    250,
    240,
    230,
    21,
    169,
    240
  ],
  [
    "FAF3F0",
    "Fantasy",
    250,
    243,
    240,
    12,
    127,
    244
  ],
  [
    "FAF7D6",
    "Citrine White",
    250,
    247,
    214,
    38,
    199,
    232
  ],
  [
    "FAFAFA",
    "Alabaster",
    250,
    250,
    250,
    0,
    0,
    250
  ],
  [
    "FAFDE4",
    "Hint of Yellow",
    250,
    253,
    228,
    47,
    219,
    240
  ],
  [
    "FAFFA4",
    "Milan",
    250,
    255,
    164,
    44,
    254,
    209
  ],
  [
    "FB607F",
    "Brink Pink",
    251,
    96,
    127,
    -8,
    242,
    173
  ],
  [
    "FB8989",
    "Geraldine",
    251,
    137,
    137,
    0,
    238,
    194
  ],
  [
    "FBA0E3",
    "Lavender Rose",
    251,
    160,
    227,
    -31,
    234,
    205
  ],
  [
    "FBA129",
    "Sea Buckthorn",
    251,
    161,
    41,
    24,
    245,
    146
  ],
  [
    "FBAC13",
    "Sun",
    251,
    172,
    19,
    28,
    246,
    135
  ],
  [
    "FBAED2",
    "Lavender Pink",
    251,
    174,
    210,
    -19,
    230,
    212
  ],
  [
    "FBB2A3",
    "Rose Bud",
    251,
    178,
    163,
    7,
    233,
    207
  ],
  [
    "FBBEDA",
    "Cupid",
    251,
    190,
    218,
    -19,
    225,
    220
  ],
  [
    "FBCCE7",
    "Classic Rose",
    251,
    204,
    231,
    -24,
    217,
    227
  ],
  [
    "FBCEB1",
    "Apricot Peach",
    251,
    206,
    177,
    16,
    230,
    213
  ],
  [
    "FBE7B2",
    "Banana Mania",
    251,
    231,
    178,
    30,
    229,
    214
  ],
  [
    "FBE870",
    "Marigold Yellow",
    251,
    232,
    112,
    36,
    241,
    181
  ],
  [
    "FBE96C",
    "Festival",
    251,
    233,
    108,
    37,
    241,
    179
  ],
  [
    "FBEA8C",
    "Sweet Corn",
    251,
    234,
    140,
    35,
    237,
    195
  ],
  [
    "FBEC5D",
    "Candy Corn",
    251,
    236,
    93,
    38,
    242,
    171
  ],
  [
    "FBF9F9",
    "Hint of Red",
    251,
    249,
    249,
    0,
    50,
    250
  ],
  [
    "FBFFBA",
    "Shalimar",
    251,
    255,
    186,
    44,
    255,
    220
  ],
  [
    "FC0FC0",
    "Shocking Pink",
    252,
    15,
    192,
    -31,
    248,
    133
  ],
  [
    "FC80A5",
    "Tickle Me Pink",
    252,
    128,
    165,
    -12,
    243,
    190
  ],
  [
    "FC9C1D",
    "Tree Poppy",
    252,
    156,
    29,
    24,
    248,
    140
  ],
  [
    "FCC01E",
    "Lightning Yellow",
    252,
    192,
    30,
    31,
    248,
    141
  ],
  [
    "FCD667",
    "Goldenrod",
    252,
    214,
    103,
    31,
    245,
    177
  ],
  [
    "FCD917",
    "Candlelight",
    252,
    217,
    23,
    36,
    248,
    137
  ],
  [
    "FCDA98",
    "Cherokee",
    252,
    218,
    152,
    28,
    240,
    202
  ],
  [
    "FCF4D0",
    "Double Pearl Lusta",
    252,
    244,
    208,
    34,
    224,
    230
  ],
  [
    "FCF4DC",
    "Pearl Lusta",
    252,
    244,
    220,
    31,
    214,
    236
  ],
  [
    "FCF8F7",
    "Vista White",
    252,
    248,
    247,
    8,
    115,
    249
  ],
  [
    "FCFBF3",
    "Bianca",
    252,
    251,
    243,
    37,
    153,
    247
  ],
  [
    "FCFEDA",
    "Moon Glow",
    252,
    254,
    218,
    44,
    241,
    236
  ],
  [
    "FCFFE7",
    "China Ivory",
    252,
    255,
    231,
    47,
    254,
    243
  ],
  [
    "FCFFF9",
    "Ceramic",
    252,
    255,
    249,
    63,
    255,
    252
  ],
  [
    "FD0E35",
    "Torch Red",
    253,
    14,
    53,
    -6,
    250,
    133
  ],
  [
    "FD5B78",
    "Wild Watermelon",
    253,
    91,
    120,
    -7,
    248,
    172
  ],
  [
    "FD7B33",
    "Crusta",
    253,
    123,
    51,
    15,
    250,
    152
  ],
  [
    "FD7C07",
    "Sorbus",
    253,
    124,
    7,
    20,
    250,
    130
  ],
  [
    "FD9FA2",
    "Sweet Pink",
    253,
    159,
    162,
    -1,
    244,
    206
  ],
  [
    "FDD5B1",
    "Light Apricot",
    253,
    213,
    177,
    20,
    242,
    215
  ],
  [
    "FDD7E4",
    "Pig Pink",
    253,
    215,
    228,
    -14,
    230,
    234
  ],
  [
    "FDE1DC",
    "Cinderella",
    253,
    225,
    220,
    6,
    227,
    236
  ],
  [
    "FDE295",
    "Golden Glow",
    253,
    226,
    149,
    31,
    245,
    201
  ],
  [
    "FDE910",
    "Lemon",
    253,
    233,
    16,
    38,
    250,
    134
  ],
  [
    "FDF5E6",
    "Old Lace",
    253,
    245,
    230,
    27,
    217,
    241
  ],
  [
    "FDF6D3",
    "Half Colonial White",
    253,
    246,
    211,
    35,
    232,
    232
  ],
  [
    "FDF7AD",
    "Drover",
    253,
    247,
    173,
    39,
    242,
    213
  ],
  [
    "FDFEB8",
    "Pale Prim",
    253,
    254,
    184,
    43,
    247,
    219
  ],
  [
    "FDFFD5",
    "Cumulus",
    253,
    255,
    213,
    44,
    255,
    234
  ],
  [
    "FE28A2",
    "Persian Rose",
    254,
    40,
    162,
    -24,
    252,
    147
  ],
  [
    "FE4C40",
    "Sunset Orange",
    254,
    76,
    64,
    2,
    252,
    159
  ],
  [
    "FE6F5E",
    "Bittersweet",
    254,
    111,
    94,
    4,
    251,
    174
  ],
  [
    "FE9D04",
    "California",
    254,
    157,
    4,
    26,
    252,
    129
  ],
  [
    "FEA904",
    "Yellow Sea",
    254,
    169,
    4,
    28,
    252,
    129
  ],
  [
    "FEBAAD",
    "Melon",
    254,
    186,
    173,
    6,
    248,
    213
  ],
  [
    "FED33C",
    "Bright Sun",
    254,
    211,
    60,
    33,
    252,
    157
  ],
  [
    "FED85D",
    "Dandelion",
    254,
    216,
    93,
    32,
    251,
    173
  ],
  [
    "FEDB8D",
    "Salomie",
    254,
    219,
    141,
    29,
    250,
    197
  ],
  [
    "FEE5AC",
    "Cape Honey",
    254,
    229,
    172,
    29,
    248,
    213
  ],
  [
    "FEEBF3",
    "Remy",
    254,
    235,
    243,
    -17,
    230,
    244
  ],
  [
    "FEEFCE",
    "Oasis",
    254,
    239,
    206,
    29,
    244,
    230
  ],
  [
    "FEF0EC",
    "Bridesmaid",
    254,
    240,
    236,
    9,
    229,
    245
  ],
  [
    "FEF2C7",
    "Beeswax",
    254,
    242,
    199,
    33,
    246,
    226
  ],
  [
    "FEF3D8",
    "Bleach White",
    254,
    243,
    216,
    30,
    242,
    235
  ],
  [
    "FEF4CC",
    "Pipi",
    254,
    244,
    204,
    34,
    245,
    229
  ],
  [
    "FEF4DB",
    "Half Spanish White",
    254,
    244,
    219,
    30,
    241,
    236
  ],
  [
    "FEF4F8",
    "Wisp Pink",
    254,
    244,
    248,
    -16,
    212,
    249
  ],
  [
    "FEF5F1",
    "Provincial Pink",
    254,
    245,
    241,
    13,
    221,
    247
  ],
  [
    "FEF7DE",
    "Half Dutch White",
    254,
    247,
    222,
    33,
    240,
    238
  ],
  [
    "FEF8E2",
    "Solitaire",
    254,
    248,
    226,
    33,
    238,
    240
  ],
  [
    "FEF8FF",
    "White Pointer",
    254,
    248,
    255,
    206,
    255,
    251
  ],
  [
    "FEF9E3",
    "Off Yellow",
    254,
    249,
    227,
    34,
    237,
    240
  ],
  [
    "FEFCED",
    "Orange White",
    254,
    252,
    237,
    37,
    228,
    245
  ],
  [
    "FF0000",
    "Red",
    255,
    0,
    0,
    0,
    255,
    127
  ],
  [
    "FF007F",
    "Rose",
    255,
    0,
    127,
    -21,
    255,
    127
  ],
  [
    "FF00CC",
    "Purple Pizzazz",
    255,
    0,
    204,
    -34,
    255,
    127
  ],
  [
    "FF00FF",
    "Magenta / Fuchsia",
    255,
    0,
    255,
    -42,
    255,
    127
  ],
  [
    "FF2400",
    "Scarlet",
    255,
    36,
    0,
    6,
    255,
    127
  ],
  [
    "FF3399",
    "Wild Strawberry",
    255,
    51,
    153,
    -21,
    255,
    153
  ],
  [
    "FF33CC",
    "Razzle Dazzle Rose",
    255,
    51,
    204,
    -31,
    255,
    153
  ],
  [
    "FF355E",
    "Radical Red",
    255,
    53,
    94,
    -8,
    254,
    154
  ],
  [
    "FF3F34",
    "Red Orange",
    255,
    63,
    52,
    2,
    255,
    153
  ],
  [
    "FF4040",
    "Coral Red",
    255,
    64,
    64,
    0,
    255,
    159
  ],
  [
    "FF4D00",
    "Vermilion",
    255,
    77,
    0,
    12,
    255,
    127
  ],
  [
    "FF4F00",
    "International Orange",
    255,
    79,
    0,
    13,
    255,
    127
  ],
  [
    "FF6037",
    "Outrageous Orange",
    255,
    96,
    55,
    8,
    255,
    155
  ],
  [
    "FF6600",
    "Blaze Orange",
    255,
    102,
    0,
    17,
    255,
    127
  ],
  [
    "FF66FF",
    "Pink Flamingo",
    255,
    102,
    255,
    -42,
    254,
    178
  ],
  [
    "FF681F",
    "Orange",
    255,
    104,
    31,
    13,
    255,
    143
  ],
  [
    "FF69B4",
    "Hot Pink",
    255,
    105,
    180,
    -21,
    254,
    179
  ],
  [
    "FF6B53",
    "Persimmon",
    255,
    107,
    83,
    5,
    255,
    169
  ],
  [
    "FF6FFF",
    "Blush Pink",
    255,
    111,
    255,
    -42,
    255,
    183
  ],
  [
    "FF7034",
    "Burning Orange",
    255,
    112,
    52,
    12,
    255,
    153
  ],
  [
    "FF7518",
    "Pumpkin",
    255,
    117,
    24,
    17,
    255,
    139
  ],
  [
    "FF7D07",
    "Flamenco",
    255,
    125,
    7,
    20,
    254,
    131
  ],
  [
    "FF7F00",
    "Flush Orange",
    255,
    127,
    0,
    21,
    255,
    127
  ],
  [
    "FF7F50",
    "Coral",
    255,
    127,
    80,
    11,
    255,
    167
  ],
  [
    "FF8C69",
    "Salmon",
    255,
    140,
    105,
    9,
    254,
    179
  ],
  [
    "FF9000",
    "Pizazz",
    255,
    144,
    0,
    24,
    255,
    127
  ],
  [
    "FF910F",
    "West Side",
    255,
    145,
    15,
    23,
    255,
    135
  ],
  [
    "FF91A4",
    "Pink Salmon",
    255,
    145,
    164,
    -7,
    255,
    200
  ],
  [
    "FF9933",
    "Neon Carrot",
    255,
    153,
    51,
    21,
    255,
    153
  ],
  [
    "FF9966",
    "Atomic Tangerine",
    255,
    153,
    102,
    14,
    254,
    178
  ],
  [
    "FF9980",
    "Vivid Tangerine",
    255,
    153,
    128,
    8,
    255,
    191
  ],
  [
    "FF9E2C",
    "Sunshade",
    255,
    158,
    44,
    22,
    255,
    149
  ],
  [
    "FFA000",
    "Orange Peel",
    255,
    160,
    0,
    26,
    255,
    127
  ],
  [
    "FFA194",
    "Mona Lisa",
    255,
    161,
    148,
    5,
    255,
    201
  ],
  [
    "FFA500",
    "Web Orange",
    255,
    165,
    0,
    27,
    255,
    127
  ],
  [
    "FFA6C9",
    "Carnation Pink",
    255,
    166,
    201,
    -16,
    254,
    210
  ],
  [
    "FFAB81",
    "Hit Pink",
    255,
    171,
    129,
    14,
    255,
    192
  ],
  [
    "FFAE42",
    "Yellow Orange",
    255,
    174,
    66,
    24,
    255,
    160
  ],
  [
    "FFB0AC",
    "Cornflower Lilac",
    255,
    176,
    172,
    2,
    255,
    213
  ],
  [
    "FFB1B3",
    "Sundown",
    255,
    177,
    179,
    -1,
    255,
    216
  ],
  [
    "FFB31F",
    "My Sin",
    255,
    179,
    31,
    28,
    255,
    143
  ],
  [
    "FFB555",
    "Texas Rose",
    255,
    181,
    85,
    24,
    255,
    170
  ],
  [
    "FFB7D5",
    "Cotton Candy",
    255,
    183,
    213,
    -17,
    255,
    219
  ],
  [
    "FFB97B",
    "Macaroni and Cheese",
    255,
    185,
    123,
    19,
    255,
    189
  ],
  [
    "FFBA00",
    "Selective Yellow",
    255,
    186,
    0,
    31,
    255,
    127
  ],
  [
    "FFBD5F",
    "Koromiko",
    255,
    189,
    95,
    24,
    255,
    175
  ],
  [
    "FFBF00",
    "Amber",
    255,
    191,
    0,
    31,
    255,
    127
  ],
  [
    "FFC0A8",
    "Wax Flower",
    255,
    192,
    168,
    11,
    254,
    211
  ],
  [
    "FFC0CB",
    "Pink",
    255,
    192,
    203,
    -7,
    255,
    223
  ],
  [
    "FFC3C0",
    "Your Pink",
    255,
    195,
    192,
    2,
    255,
    223
  ],
  [
    "FFC901",
    "Supernova",
    255,
    201,
    1,
    33,
    255,
    128
  ],
  [
    "FFCBA4",
    "Flesh",
    255,
    203,
    164,
    18,
    254,
    209
  ],
  [
    "FFCC33",
    "Sunglow",
    255,
    204,
    51,
    31,
    255,
    153
  ],
  [
    "FFCC5C",
    "Golden Tainoi",
    255,
    204,
    92,
    29,
    255,
    173
  ],
  [
    "FFCC99",
    "Peach Orange",
    255,
    204,
    153,
    21,
    255,
    204
  ],
  [
    "FFCD8C",
    "Chardonnay",
    255,
    205,
    140,
    24,
    255,
    197
  ],
  [
    "FFD1DC",
    "Pastel Pink",
    255,
    209,
    220,
    -10,
    255,
    232
  ],
  [
    "FFD2B7",
    "Romantic",
    255,
    210,
    183,
    15,
    255,
    219
  ],
  [
    "FFD38C",
    "Grandis",
    255,
    211,
    140,
    26,
    255,
    197
  ],
  [
    "FFD700",
    "Gold",
    255,
    215,
    0,
    35,
    255,
    127
  ],
  [
    "FFD800",
    "School bus Yellow",
    255,
    216,
    0,
    36,
    255,
    127
  ],
  [
    "FFD8D9",
    "Cosmos",
    255,
    216,
    217,
    -1,
    255,
    235
  ],
  [
    "FFDB58",
    "Mustard",
    255,
    219,
    88,
    33,
    255,
    171
  ],
  [
    "FFDCD6",
    "Peach Schnapps",
    255,
    220,
    214,
    6,
    255,
    234
  ],
  [
    "FFDDAF",
    "Caramel",
    255,
    221,
    175,
    24,
    255,
    215
  ],
  [
    "FFDDCD",
    "Tuft Bush",
    255,
    221,
    205,
    13,
    255,
    230
  ],
  [
    "FFDDCF",
    "Watusi",
    255,
    221,
    207,
    12,
    255,
    231
  ],
  [
    "FFDDF4",
    "Pink Lace",
    255,
    221,
    244,
    -28,
    255,
    238
  ],
  [
    "FFDEAD",
    "Navajo White",
    255,
    222,
    173,
    25,
    255,
    214
  ],
  [
    "FFDEB3",
    "Frangipani",
    255,
    222,
    179,
    24,
    255,
    217
  ],
  [
    "FFE1DF",
    "Pippin",
    255,
    225,
    223,
    2,
    255,
    239
  ],
  [
    "FFE1F2",
    "Pale Rose",
    255,
    225,
    242,
    -24,
    255,
    240
  ],
  [
    "FFE2C5",
    "Negroni",
    255,
    226,
    197,
    21,
    254,
    226
  ],
  [
    "FFE5A0",
    "Cream Brulee",
    255,
    229,
    160,
    30,
    255,
    207
  ],
  [
    "FFE5B4",
    "Peach",
    255,
    229,
    180,
    27,
    255,
    217
  ],
  [
    "FFE6C7",
    "Tequila",
    255,
    230,
    199,
    23,
    254,
    227
  ],
  [
    "FFE772",
    "Kournikova",
    255,
    231,
    114,
    35,
    255,
    184
  ],
  [
    "FFEAC8",
    "Sandy Beach",
    255,
    234,
    200,
    26,
    254,
    227
  ],
  [
    "FFEAD4",
    "Karry",
    255,
    234,
    212,
    21,
    255,
    233
  ],
  [
    "FFEC13",
    "Broom",
    255,
    236,
    19,
    39,
    255,
    137
  ],
  [
    "FFEDBC",
    "Colonial White",
    255,
    237,
    188,
    31,
    255,
    221
  ],
  [
    "FFEED8",
    "Derby",
    255,
    238,
    216,
    23,
    255,
    235
  ],
  [
    "FFEFA1",
    "Vis Vis",
    255,
    239,
    161,
    35,
    255,
    208
  ],
  [
    "FFEFC1",
    "Egg White",
    255,
    239,
    193,
    31,
    255,
    224
  ],
  [
    "FFEFD5",
    "Papaya Whip",
    255,
    239,
    213,
    26,
    255,
    234
  ],
  [
    "FFEFEC",
    "Fair Pink",
    255,
    239,
    236,
    6,
    255,
    245
  ],
  [
    "FFF0DB",
    "Peach Cream",
    255,
    240,
    219,
    24,
    255,
    237
  ],
  [
    "FFF0F5",
    "Lavender blush",
    255,
    240,
    245,
    -14,
    255,
    247
  ],
  [
    "FFF14F",
    "Gorse",
    255,
    241,
    79,
    39,
    255,
    167
  ],
  [
    "FFF1B5",
    "Buttermilk",
    255,
    241,
    181,
    34,
    255,
    218
  ],
  [
    "FFF1D8",
    "Pink Lady",
    255,
    241,
    216,
    27,
    255,
    235
  ],
  [
    "FFF1EE",
    "Forget Me Not",
    255,
    241,
    238,
    7,
    255,
    246
  ],
  [
    "FFF1F9",
    "Tutu",
    255,
    241,
    249,
    -24,
    255,
    248
  ],
  [
    "FFF39D",
    "Picasso",
    255,
    243,
    157,
    37,
    255,
    206
  ],
  [
    "FFF3F1",
    "Chardon",
    255,
    243,
    241,
    6,
    255,
    248
  ],
  [
    "FFF46E",
    "Paris Daisy",
    255,
    244,
    110,
    39,
    255,
    182
  ],
  [
    "FFF4CE",
    "Barley White",
    255,
    244,
    206,
    32,
    255,
    230
  ],
  [
    "FFF4DD",
    "Egg Sour",
    255,
    244,
    221,
    28,
    255,
    238
  ],
  [
    "FFF4E0",
    "Sazerac",
    255,
    244,
    224,
    27,
    255,
    239
  ],
  [
    "FFF4E8",
    "Serenade",
    255,
    244,
    232,
    22,
    254,
    243
  ],
  [
    "FFF4F3",
    "Chablis",
    255,
    244,
    243,
    3,
    255,
    249
  ],
  [
    "FFF5EE",
    "Seashell Peach",
    255,
    245,
    238,
    17,
    255,
    246
  ],
  [
    "FFF5F3",
    "Sauvignon",
    255,
    245,
    243,
    7,
    255,
    249
  ],
  [
    "FFF6D4",
    "Milk Punch",
    255,
    246,
    212,
    33,
    255,
    233
  ],
  [
    "FFF6DF",
    "Varden",
    255,
    246,
    223,
    30,
    255,
    239
  ],
  [
    "FFF6F5",
    "Rose White",
    255,
    246,
    245,
    4,
    255,
    250
  ],
  [
    "FFF8D1",
    "Baja White",
    255,
    248,
    209,
    36,
    255,
    232
  ],
  [
    "FFF9E2",
    "Gin Fizz",
    255,
    249,
    226,
    33,
    255,
    240
  ],
  [
    "FFF9E6",
    "Early Dawn",
    255,
    249,
    230,
    32,
    254,
    242
  ],
  [
    "FFFACD",
    "Lemon Chiffon",
    255,
    250,
    205,
    38,
    255,
    230
  ],
  [
    "FFFAF4",
    "Bridal Heath",
    255,
    250,
    244,
    23,
    255,
    249
  ],
  [
    "FFFBDC",
    "Scotch Mist",
    255,
    251,
    220,
    37,
    255,
    237
  ],
  [
    "FFFBF9",
    "Soapstone",
    255,
    251,
    249,
    14,
    255,
    252
  ],
  [
    "FFFC99",
    "Witch Haze",
    255,
    252,
    153,
    41,
    255,
    204
  ],
  [
    "FFFCEA",
    "Buttery White",
    255,
    252,
    234,
    36,
    254,
    244
  ],
  [
    "FFFCEE",
    "Island Spice",
    255,
    252,
    238,
    35,
    255,
    246
  ],
  [
    "FFFDD0",
    "Cream",
    255,
    253,
    208,
    40,
    255,
    231
  ],
  [
    "FFFDE6",
    "Chilean Heath",
    255,
    253,
    230,
    39,
    254,
    242
  ],
  [
    "FFFDE8",
    "Travertine",
    255,
    253,
    232,
    38,
    254,
    243
  ],
  [
    "FFFDF3",
    "Orchid White",
    255,
    253,
    243,
    35,
    255,
    249
  ],
  [
    "FFFDF4",
    "Quarter Pearl Lusta",
    255,
    253,
    244,
    34,
    255,
    249
  ],
  [
    "FFFEE1",
    "Half and Half",
    255,
    254,
    225,
    41,
    255,
    240
  ],
  [
    "FFFEEC",
    "Apricot White",
    255,
    254,
    236,
    40,
    255,
    245
  ],
  [
    "FFFEF0",
    "Rice Cake",
    255,
    254,
    240,
    39,
    255,
    247
  ],
  [
    "FFFEF6",
    "Black White",
    255,
    254,
    246,
    37,
    255,
    250
  ],
  [
    "FFFEFD",
    "Romance",
    255,
    254,
    253,
    21,
    255,
    254
  ],
  [
    "FFFF00",
    "Yellow",
    255,
    255,
    0,
    42,
    255,
    127
  ],
  [
    "FFFF66",
    "Laser Lemon",
    255,
    255,
    102,
    42,
    254,
    178
  ],
  [
    "FFFF99",
    "Pale Canary",
    255,
    255,
    153,
    42,
    255,
    204
  ],
  [
    "FFFFB4",
    "Portafino",
    255,
    255,
    180,
    42,
    255,
    217
  ],
  [
    "FFFFF0",
    "Ivory",
    255,
    255,
    240,
    42,
    255,
    247
  ],
  [
    "FFFFFF",
    "White",
    255,
    255,
    255,
    0,
    0,
    255
  ]
]
